@@ -40,7 +40,7 @@
 #include "qfile.h"
 #include "qfiledefs_p.h"
 
-#if defined(_OS_MAC_) || defined(_OS_MSDOS_) || defined(_OS_WIN32_) || defined(_OS_OS2_) || defined(_OS_CYGWIN_)
+#if (defined(_OS_MAC_) && (!defined(_OS_UNIX_))) || defined(_OS_MSDOS_) || defined(_OS_WIN32_) || defined(_OS_OS2_) || defined(_OS_CYGWIN_)
 # define HAS_TEXT_FILEMODE			// has translate/text filemode
 #endif
 #if defined(O_NONBLOCK)
@@ -175,7 +175,11 @@ bool QFile::open( int m )
 	}
 #if defined(HAS_TEXT_FILEMODE)
 	if ( isTranslated() )
+#ifdef __CYGWIN__
+          /* Do nothing, allowing the Cygwin mount mode to take effect. */;
+#else
 	    oflags |= OPEN_TEXT;
+#endif
 	else
 	    oflags |= OPEN_BINARY;
 #endif
@@ -214,7 +218,11 @@ bool QFile::open( int m )
 	qstrcpy( perm2, perm );
 #if defined(HAS_TEXT_FILEMODE)
 	if ( isTranslated() )
+#ifdef __CYGWIN__
+            /* Do nothing, allowing the Cygwin mount mode to take effect. */;
+#else
 	    strcat( perm2, "t" );
+#endif
 	else
 	    strcat( perm2, "b" );
 #endif
@@ -624,3 +632,37 @@ void QFile::close()
 
     return;
 }
+
+int64 QFile::pos() const
+{
+  if (isOpen())
+  {
+    // TODO: support 64 bit size
+    return ftell( fh );
+  }
+  return -1;
+}
+
+int64 QFile::toEnd() 
+{
+  if (isOpen())
+  {
+     // TODO: support 64 bit size
+     if (fseek( fh, 0, SEEK_END )!=-1)
+     {
+       return ftell( fh );
+     }
+  }
+  return -1;
+}
+
+bool QFile::seek( int64 pos )
+{
+  if (isOpen())
+  {
+    // TODO: support 64 bit size
+    return fseek( fh, pos, SEEK_SET )!=-1;
+  }
+  return FALSE;
+}
+
