@@ -2,7 +2,7 @@
  *
  * $Id: classdef.h,v 1.39 2001/03/19 19:27:39 root Exp $
  *
- * Copyright (C) 1997-2010 by Dimitri van Heesch.
+ * Copyright (C) 1997-2011 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -23,7 +23,7 @@
 #include <qdict.h>
 #include <qstrlist.h>
 
-//#include "entry.h"
+#include "util.h"
 #include "memberlist.h"
 #include "definition.h"
 #include "sortdict.h"
@@ -96,6 +96,7 @@ class ClassDef : public Definition
 
     /*! Returns the unique base name (without extension) of the class's file on disk */
     QCString getOutputFileBase() const; 
+    QCString getXmlOutputFileBase() const;
     QCString getInstanceOutputFileBase() const; 
     QCString getFileBase() const;
 
@@ -237,6 +238,9 @@ class ClassDef : public Definition
     /*! Returns TRUE if this class is implemented in Objective-C */
     bool isObjectiveC() const;
 
+    /*! Returns TRUE if this class is implemented in C# */
+    bool isCSharp() const;
+
     /*! Returns the class of which this is a category (Objective-C only) */
     ClassDef *categoryOf() const;
 
@@ -260,6 +264,9 @@ class ClassDef : public Definition
 
     bool isUsedOnly() const;
 
+    QCString anchor() const;
+    bool isEmbeddedInGroupDocs() const;
+
     //-----------------------------------------------------------------------------------
     // --- setters ----
     //-----------------------------------------------------------------------------------
@@ -282,7 +289,7 @@ class ClassDef : public Definition
     void addUsedClass(ClassDef *cd,const char *accessName);
     void addUsedByClass(ClassDef *cd,const char *accessName);
     void setIsStatic(bool b);
-    void setIsObjectiveC(bool b);
+    void setLanguage(SrcLangExt lang);
     void setCompoundType(CompoundType t);
     void setClassName(const char *name);
 
@@ -304,6 +311,7 @@ class ClassDef : public Definition
     void addListReferences();
     void computeAnchors();
     void mergeMembers();
+    void sortMemberLists();
     void distributeMemberGroupDocumentation();
     void writeDocumentation(OutputList &ol);
     void writeDocumentationForInnerClasses(OutputList &ol);
@@ -311,7 +319,11 @@ class ClassDef : public Definition
     void writeMemberList(OutputList &ol);
     void writeDeclaration(OutputList &ol,MemberDef *md,bool inGroup);
     void writeQuickMemberLinks(OutputList &ol,MemberDef *md) const;
+    void writeSummaryLinks(OutputList &ol);
     void reclassifyMember(MemberDef *md,MemberDef::MemberType t);
+    void writeInlineDocumentation(OutputList &ol);
+    void writeDeclarationLink(OutputList &ol,bool &found,
+                              const char *header,bool localNames);
     
     bool visited;
 
@@ -322,28 +334,32 @@ class ClassDef : public Definition
     void showUsedFiles(OutputList &ol);
 
   private: 
+    void writeTagFileMarker(OutputList &ol);
+    void writeDocumentationContents(OutputList &ol,const QCString &pageTitle);
     void internalInsertMember(MemberDef *md,Protection prot,bool addToAllList);
     QCString getMemberListFileName() const;
     void addMemberToList(MemberList::ListType lt,MemberDef *md,bool isBrief);
     MemberList *createMemberList(MemberList::ListType lt);
     void writeMemberDeclarations(OutputList &ol,MemberList::ListType lt,const QCString &title,
-                                 const char *subTitle=0);
-    void writeMemberDocumentation(OutputList &ol,MemberList::ListType lt,const QCString &title);
+                                 const char *subTitle=0,bool showInline=FALSE);
+    void writeMemberDocumentation(OutputList &ol,MemberList::ListType lt,const QCString &title,bool showInline=FALSE);
     void writePlainMemberDeclaration(OutputList &ol,MemberList::ListType lt,bool inGroup);
     void writeBriefDescription(OutputList &ol,bool exampleFlag);
     void writeDetailedDescription(OutputList &ol,const QCString &pageType,bool exampleFlag,
-                                  const QCString &title);
+                                  const QCString &title,const QCString &anchor=QCString());
     void writeIncludeFiles(OutputList &ol);
     void writeAllMembersLink(OutputList &ol);
     void writeInheritanceGraph(OutputList &ol);
     void writeCollaborationGraph(OutputList &ol);
-    void writeMemberGroups(OutputList &ol);
+    void writeMemberGroups(OutputList &ol,bool showInline=FALSE);
     void writeNestedClasses(OutputList &ol,const QCString &title);
     void startMemberDeclarations(OutputList &ol);
     void endMemberDeclarations(OutputList &ol);
     void startMemberDocumentation(OutputList &ol);
     void endMemberDocumentation(OutputList &ol);
     void writeAuthorSection(OutputList &ol);
+    void writeMoreLink(OutputList &ol,const QCString &anchor);
+    void writeDetailedDocumentationBody(OutputList &ol);
     
     ClassDefImpl *m_impl;
 
