@@ -3,7 +3,7 @@
  * 
  *
  *
- * Copyright (C) 1997-2008 by Dimitri van Heesch.
+ * Copyright (C) 1997-2011 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -110,7 +110,12 @@ enum CommandType
   CMD_ENDMANONLY   = 76,
   CMD_INCWITHLINES = 77,
   CMD_INHERITDOC   = 78,
-  CMD_TPARAM       = 79 | SIMPLESECT_BIT
+  CMD_TPARAM       = 79 | SIMPLESECT_BIT,
+  CMD_COPYBRIEF    = 80,
+  CMD_COPYDETAILS  = 81,
+  CMD_QUOTE        = 82,
+  CMD_MSCFILE      = 83,
+  CMD_DCOLON       = 84
 };
 
 enum HtmlTagType
