@@ -2,7 +2,7 @@
  *
  * $Id: index.cpp,v 1.30 1999/03/06 22:15:39 root Exp $
  *
- * Copyright (C) 1997-2010 by Dimitri van Heesch.
+ * Copyright (C) 1997-2011 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -18,7 +18,7 @@
 #include "qtbc.h"
 #include <ctype.h>
 #include <qregexp.h>
-#include <md5.h>
+#include "md5.h"
 #include <stdio.h>
 #include <stdlib.h>
 #include <assert.h>
@@ -252,7 +252,6 @@ void Definition::removeFromMap(Definition *d)
     DefinitionIntf *di=Doxygen::symbolMap->find(symbolName);
     if (di)
     {
-      ASSERT(di!=0);
       if (di!=d) // symbolName not unique
       {
         //printf("  removing from list: %p!\n",di);
@@ -435,6 +434,18 @@ void Definition::setDocumentation(const char *d,const char *docFile,int docLine,
 
 #define uni_isupper(c) (QChar(c).category()==QChar::Letter_Uppercase)
 
+// do a UTF-8 aware search for the last real character and return TRUE 
+// if that is a multibyte one.
+static bool lastCharIsMultibyte(const QCString &s)
+{
+  int l = s.length();
+  int p = 0;
+  int pp = -1;
+  while ((p=nextUtf8CharPosition(s,l,p))<l) pp=p;
+  if (pp==-1 || ((uchar)s[pp])<0x80) return FALSE;
+  return TRUE;
+}
+
 void Definition::_setBriefDescription(const char *b,const char *briefFile,int briefLine)
 {
   static QCString outputLanguage = Config_getEnum("OUTPUT_LANGUAGE");
@@ -447,11 +458,12 @@ void Definition::_setBriefDescription(const char *b,const char *briefFile,int br
   int bl = brief.length();
   if (bl>0 && needsDot) // add punctuation if needed
   {
-    switch(brief.at(bl-1))
+    int c = brief.at(bl-1);
+    switch(c)
     {
-      case '.': case '!': case '?': case '>': case ':': break;
+      case '.': case '!': case '?': case '>': case ':': case ')': break;
       default: 
-        if (uni_isupper(brief.at(0))) brief+='.'; 
+        if (uni_isupper(brief.at(0)) && !lastCharIsMultibyte(brief)) brief+='.'; 
         break;
     }
   }
@@ -474,6 +486,11 @@ void Definition::_setBriefDescription(const char *b,const char *briefFile,int br
       m_impl->brief->file = briefFile;
       m_impl->brief->line = briefLine;
     }
+    else
+    {
+      m_impl->brief->file = briefFile;
+      m_impl->brief->line = 1;
+    }
   }
 }
 
@@ -527,7 +544,7 @@ static bool readCodeFragment(const char *fileName,
   static bool filterSourceFiles = Config_getBool("FILTER_SOURCE_FILES");
   //printf("readCodeFragment(%s,%d,%d)\n",fileName,startLine,endLine);
   if (fileName==0 || fileName[0]==0) return FALSE; // not a valid file name
-  QCString filter = getFileFilter(fileName);
+  QCString filter = getFileFilter(fileName,TRUE);
   FILE *f=0;
   bool usePipe = !filter.isEmpty() && filterSourceFiles;
   if (!usePipe) // no filter given or wanted
@@ -558,6 +575,7 @@ static bool readCodeFragment(const char *fileName,
       char cn=0;
       while (lineNr<=endLine && !feof(f) && !found)
       {
+        int pc=0;
         while ((c=fgetc(f))!='{' && c!=':' && c!=EOF) 
         {
           //printf("parsing char `%c'\n",c);
@@ -569,10 +587,24 @@ static bool readCodeFragment(const char *fileName,
           {
             col+=Config_getInt("TAB_SIZE") - (col%Config_getInt("TAB_SIZE"));
           }
+          else if (pc=='/' && c=='/') // skip single line comment
+          {
+            while ((c=fgetc(f))!='\n' && c!=EOF) pc=c;
+            if (c=='\n') lineNr++,col=0;
+          }
+          else if (pc=='/' && c=='*') // skip C style comment
+          {
+            while (((c=fgetc(f))!='/' || pc!='*') && c!=EOF) 
+            {
+              if (c=='\n') lineNr++,col=0;
+              pc=c;
+            }
+          }
           else
           {
             col++;
           }
+          pc = c;
         }
         if (c==':')
         {
@@ -790,8 +822,8 @@ void Definition::writeSourceDef(OutputList &ol,const char *)
 
 void Definition::setBodySegment(int bls,int ble) 
 {
-  makeResident();
   //printf("setBodySegment(%d,%d) for %s\n",bls,ble,name().data());
+  makeResident();
   if (m_impl->body==0) m_impl->body = new BodyInfo;
   m_impl->body->startLine=bls; 
   m_impl->body->endLine=ble; 
@@ -828,7 +860,6 @@ void Definition::writeInlineCode(OutputList &ol,const char *scopeName)
       //printf("Read:\n`%s'\n\n",codeFragment.data());
       MemberDef *thisMd = 0;
       if (definitionType()==TypeMember) thisMd = (MemberDef *)this;
-      ol.startParagraph();
       ol.startCodeFragment();
       pIntf->parseCode(ol,               // codeOutIntf
                        scopeName,        // scope
@@ -843,7 +874,6 @@ void Definition::writeInlineCode(OutputList &ol,const char *scopeName)
                        FALSE             // show line numbers
                       );
       ol.endCodeFragment();
-      ol.endParagraph();
     }
   }
   ol.popGeneratorState();
@@ -1276,7 +1306,7 @@ void Definition::writePathFragment(OutputList &ol) const
   {
     m_impl->outerScope->writePathFragment(ol);
   }
-  ol.writeString("      <li>");
+  ol.writeString("      <li class=\"navelem\">");
   if (isLinkable())
   {
     if (definitionType()==Definition::TypeGroup && ((const GroupDef*)this)->groupTitle())
@@ -1289,7 +1319,12 @@ void Definition::writePathFragment(OutputList &ol) const
     }
     else if (definitionType()==Definition::TypeClass)
     {
-      ol.writeObjectLink(getReference(),getOutputFileBase(),0,((const ClassDef*)this)->displayName());
+      QCString name = m_impl->localName;
+      if (name.right(2)=="-p" || name.right(2)=="-g")
+      {
+        name = name.left(name.length()-2);
+      }
+      ol.writeObjectLink(getReference(),getOutputFileBase(),0,name);
     }
     else
     {
@@ -1307,14 +1342,31 @@ void Definition::writePathFragment(OutputList &ol) const
 
 void Definition::writeNavigationPath(OutputList &ol) const
 {
+  static bool generateTreeView = Config_getBool("GENERATE_TREEVIEW");
+  static bool hasCustomFooter = !Config_getString("HTML_FOOTER").isEmpty();
+
   ol.pushGeneratorState();
   ol.disableAllBut(OutputGenerator::Html);
 
-  ol.writeString("  <div class=\"navpath\">\n");
+  if (generateTreeView)
+  {
+    ol.writeString("</div>\n");
+  }
+
+  ol.writeString("  <div id=\"nav-path\" class=\"navpath\">\n");
   ol.writeString("    <ul>\n");
   writePathFragment(ol);
-  ol.writeString("    </ul>\n");
-  ol.writeString("  </div>\n");
+  if (!hasCustomFooter && generateTreeView) // write the doxygen logo as part of the navigation bar
+  {
+    ol.writeString("      <li class=\"footer\">");
+    ol.writeLogo();
+    ol.writeString("</li>\n");
+  }
+  if (!hasCustomFooter || !generateTreeView)
+  {
+    ol.writeString("    </ul>\n");
+    ol.writeString("  </div>\n");
+  }
 
   ol.popGeneratorState();
 }
