@@ -1,4 +1,4 @@
-#include <md5.h>
+#include "md5.h"
 
 #include "dirdef.h"
 #include "filename.h"
@@ -117,7 +117,7 @@ void DirDef::writeDetailedDescription(OutputList &ol,const QCString &title)
     ol.writeRuler();
     ol.pushGeneratorState();
     ol.disableAllBut(OutputGenerator::Html);
-      ol.writeAnchor(0,"_details");
+      ol.writeAnchor(0,"details");
     ol.popGeneratorState();
     ol.startGroupHeader();
     ol.parseText(title);
@@ -166,7 +166,7 @@ void DirDef::writeBriefDescription(OutputList &ol)
        )
     {
       ol.disableAllBut(OutputGenerator::Html);
-      ol.startTextLink(0,"_details");
+      ol.startTextLink(0,"details");
       ol.parseText(theTranslator->trMore());
       ol.endTextLink();
     }
@@ -191,12 +191,12 @@ void DirDef::writeDirectoryGraph(OutputList &ol)
     {
       msg("Generating dependency graph for directory %s\n",displayName().data());
       ol.disable(OutputGenerator::Man);
-      ol.startParagraph();
+      //ol.startParagraph();
       ol.startDirDepGraph();
       //TODO: ol.parseText(theTranslator->trDirDepGraph());
       ol.parseText((QCString)"Directory dependency graph for "+displayName()+":");
       ol.endDirDepGraph(dirDep);
-      ol.endParagraph();
+      //ol.endParagraph();
       ol.enableAll();
     }
   }
@@ -318,16 +318,19 @@ void DirDef::endMemberDeclarations(OutputList &ol)
 
 void DirDef::writeDocumentation(OutputList &ol)
 {
+  static bool generateTreeView = Config_getBool("GENERATE_TREEVIEW");
   ol.pushGeneratorState();
   
   QCString shortTitle=theTranslator->trDirReference(m_shortName);
   QCString title=theTranslator->trDirReference(m_dispName);
-  startFile(ol,getOutputFileBase(),name(),title,HLI_None,TRUE);
+  startFile(ol,getOutputFileBase(),name(),title,HLI_None,!generateTreeView);
 
-  // write navigation path
-  writeNavigationPath(ol);
-
-  ol.endQuickIndices();
+  if (!generateTreeView)
+  {
+    // write navigation path
+    writeNavigationPath(ol);
+    ol.endQuickIndices();
+  }
 
   startTitle(ol,getOutputFileBase());
   ol.pushGeneratorState();
@@ -396,6 +399,7 @@ void DirDef::writeDocumentation(OutputList &ol)
       case LayoutDocEntry::FileIncludedByGraph: 
       case LayoutDocEntry::FileSourceLink:
       case LayoutDocEntry::GroupClasses: 
+      case LayoutDocEntry::GroupInlineClasses: 
       case LayoutDocEntry::GroupNamespaces:
       case LayoutDocEntry::GroupDirs: 
       case LayoutDocEntry::GroupNestedGroups: 
@@ -422,35 +426,18 @@ void DirDef::writeDocumentation(OutputList &ol)
     Doxygen::tagFile << "  </compound>" << endl;
   }
 
-  endFile(ol); 
-  ol.popGeneratorState();
+  ol.endContents();
 
-
-}
-
-#if 0
-void DirDef::writePathFragment(OutputList &ol) const
-{
-  if (m_parent)
+  if (generateTreeView)
   {
-    m_parent->writePathFragment(ol);
-    ol.writeString("&nbsp;/&nbsp;");
+    writeNavigationPath(ol);
   }
-  ol.writeObjectLink(getReference(),getOutputFileBase(),0,shortName());
-}
-
-void DirDef::writeNavigationPath(OutputList &ol)
-{
-  ol.pushGeneratorState();
-  ol.disableAllBut(OutputGenerator::Html);
-
-  ol.writeString("<div class=\"nav\">\n");
-  writePathFragment(ol);
-  ol.writeString("</div>\n");
 
+  endFile(ol,TRUE); 
   ol.popGeneratorState();
+
+
 }
-#endif
 
 void DirDef::setLevel()
 {
@@ -675,7 +662,7 @@ static void writePartialDirPath(OutputList &ol,const DirDef *root,const DirDef *
   if (target->parent()!=root) 
   {
     writePartialDirPath(ol,root,target->parent());
-    ol.writeString("&nbsp;/&nbsp;");
+    ol.writeString("&#160;/&#160;");
   }
   ol.writeObjectLink(target->getReference(),target->getOutputFileBase(),0,target->shortName());
 }
@@ -685,7 +672,7 @@ static void writePartialFilePath(OutputList &ol,const DirDef *root,const FileDef
   if (fd->getDirDef() && fd->getDirDef()!=root)
   {
     writePartialDirPath(ol,root,fd->getDirDef());
-    ol.writeString("&nbsp;/&nbsp;");
+    ol.writeString("&#160;/&#160;");
   }
   if (fd->isLinkable())
   {
@@ -701,6 +688,7 @@ static void writePartialFilePath(OutputList &ol,const DirDef *root,const FileDef
 
 void DirRelation::writeDocumentation(OutputList &ol)
 {
+  static bool generateTreeView = Config_getBool("GENERATE_TREEVIEW");
   ol.pushGeneratorState();
   ol.disableAllBut(OutputGenerator::Html);
 
@@ -710,28 +698,24 @@ void DirRelation::writeDocumentation(OutputList &ol)
   QCString title=theTranslator->trDirRelation(
                  m_src->displayName()+" -> "+
                  m_dst->dir()->shortName());
-  startFile(ol,getOutputFileBase(),getOutputFileBase(),title);
+  startFile(ol,getOutputFileBase(),getOutputFileBase(),
+            title,HLI_None,!generateTreeView,m_src->getOutputFileBase());
 
-  // write navigation path
-  m_src->writeNavigationPath(ol);
+  if (!generateTreeView)
+  {
+    // write navigation path
+    m_src->writeNavigationPath(ol);
+    ol.endQuickIndices();
+  }
   ol.startContents();
 
-  //startTitle(ol,getOutputFileBase());
-  //  ol.parseText(shortTitle);
-  //endTitle(ol,getOutputFileBase(),title);
   ol.writeString("<h3>"+shortTitle+"</h3>");
-  
   ol.writeString("<table class=\"dirtab\">");
   ol.writeString("<tr class=\"dirtab\">");
-  // TODO: translate me! "File in %s"
   ol.writeString("<th class=\"dirtab\">");
   ol.parseText(theTranslator->trFileIn(m_src->pathFragment()));
-  //m_src->writePathFragment(ol);
   ol.writeString("</th>");
-  // TODO: translate me! "Includes file in %s"
   ol.writeString("<th class=\"dirtab\">");
-  //ol.writeString("Includes file in ");
-  //m_dst->dir()->writePathFragment(ol);
   ol.parseText(theTranslator->trIncludesFileIn(m_dst->dir()->pathFragment()));
   ol.writeString("</th>");
   ol.writeString("</tr>");
@@ -750,8 +734,15 @@ void DirRelation::writeDocumentation(OutputList &ol)
     ol.writeString("</tr>");
   }
   ol.writeString("</table>");
+
+  ol.endContents();
   
-  endFile(ol); 
+  if (generateTreeView)
+  {
+    m_src->writeNavigationPath(ol);
+  }
+
+  endFile(ol,TRUE); 
   ol.popGeneratorState();
 }
 
