@@ -1,6 +1,6 @@
 /******************************************************************************
  *
- * Copyright (C) 1997-2010 by Dimitri van Heesch.
+ * Copyright (C) 1997-2011 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -230,12 +230,9 @@ void DocSets::addContentsItem(bool isDir,
   }
 }
 
-void DocSets::addIndexItem(Definition *context,MemberDef *md,
-                           const char *anchor,const char *word)
+void DocSets::addIndexItem(Definition *context,MemberDef *md,const char *)
 {
-  (void)anchor;
-  (void)word;
-  if (md==0 || context==0) return; // TODO: also index non members...
+  if (md==0 && context==0) return;
 
   FileDef *fd      = 0;
   ClassDef *cd     = 0;
@@ -346,6 +343,16 @@ void DocSets::addIndexItem(Definition *context,MemberDef *md,
       case MemberDef::Event:
         type="event"; break;
     }
+    cd = md->getClassDef();
+    nd = md->getNamespaceDef();
+    if (cd) 
+    {
+      scope = cd->qualifiedName();
+    }
+    else if (nd)
+    {
+      scope = nd->name();
+    }
     writeToken(m_tts,md,type,lang,scope,md->anchor());
   }
   else if (context && context->isLinkable())
@@ -407,7 +414,7 @@ void DocSets::addIndexItem(Definition *context,MemberDef *md,
     }
     if (m_scopes.find(context->getOutputFileBase())==0)
     {
-      writeToken(m_tts,context,type,lang,0,0,decl);
+      writeToken(m_tts,context,type,lang,scope,0,decl);
       m_scopes.append(context->getOutputFileBase(),(void*)0x8);
     }
   }
