@@ -11,6 +11,12 @@
 "	font-size: 150%;\n"
 "}\n"
 "\n"
+".title {\n"
+"	font-size: 150%;\n"
+"	font-weight: bold;\n"
+"	margin: 10px 2px;\n"
+"}\n"
+"\n"
 "h2 {\n"
 "	font-size: 120%;\n"
 "}\n"
@@ -185,7 +191,7 @@
 "div.contents {\n"
 "	margin-top: 10px;\n"
 "	margin-left: 10px;\n"
-"	margin-right: 10px;\n"
+"	margin-right: 5px;\n"
 "}\n"
 "\n"
 "td.indexkey {\n"
@@ -361,6 +367,10 @@
 "        white-space: nowrap;\n"
 "}\n"
 "\n"
+".memItemRight {\n"
+"	width: 100%;\n"
+"}\n"
+"\n"
 ".memTemplParams {\n"
 "	color: ##60;\n"
 "        white-space: nowrap;\n"
@@ -388,9 +398,14 @@
 "	padding: 2px;\n"
 "}\n"
 "\n"
+".mempage {\n"
+"	width: 100%;\n"
+"}\n"
+"\n"
 ".memitem {\n"
 "	padding: 0;\n"
 "	margin-bottom: 10px;\n"
+"	margin-right: 5px;\n"
 "}\n"
 "\n"
 ".memname {\n"
@@ -724,7 +739,7 @@
 "\n"
 "dl.note\n"
 "{\n"
-"        border-color: #D0D000;\n"
+"        border-color: #D0C000;\n"
 "}\n"
 "\n"
 "dl.warning, dl.attention\n"
@@ -771,21 +786,21 @@
 " \n"
 "#projectname\n"
 "{\n"
-"	font: 300% arial,sans-serif;\n"
+"	font: 300% Tahoma, Arial,sans-serif;\n"
 "	margin: 0px;\n"
-"	padding: 0px;\n"
+"	padding: 2px 0px;\n"
 "}\n"
 "    \n"
 "#projectbrief\n"
 "{\n"
-"	font: 120% arial,sans-serif;\n"
+"	font: 120% Tahoma, Arial,sans-serif;\n"
 "	margin: 0px;\n"
 "	padding: 0px;\n"
 "}\n"
 "\n"
 "#projectnumber\n"
 "{\n"
-"	font: 50% arial,sans-serif;\n"
+"	font: 50% Tahoma, Arial,sans-serif;\n"
 "	margin: 0px;\n"
 "	padding: 0px;\n"
 "}\n"
@@ -798,3 +813,23 @@
 "	border-bottom: 1px solid ##70;\n"
 "}\n"
 "\n"
+".image\n"
+"{\n"
+"        text-align: center;\n"
+"}\n"
+"\n"
+".dotgraph\n"
+"{\n"
+"        text-align: center;\n"
+"}\n"
+"\n"
+".mscgraph\n"
+"{\n"
+"        text-align: center;\n"
+"}\n"
+"\n"
+".caption\n"
+"{\n"
+"	font-weight: bold;\n"
+"}\n"
+"\n"
