@@ -2,7 +2,7 @@
  *
  * $Id: entry.cpp,v 1.29 2001/03/19 19:27:40 root Exp $
  *
- * Copyright (C) 1997-2010 by Dimitri van Heesch.
+ * Copyright (C) 1997-2011 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -39,7 +39,7 @@ bool ArgumentList::hasDocumentation() const
   Argument *a;
   for (ali.toFirst();!hasDocs && (a=ali.current());++ali)
   {
-    hasDocs = hasDocs || a->hasDocumentation(); 
+    hasDocs = a->hasDocumentation(); 
   }
   return hasDocs;
 }
@@ -365,8 +365,8 @@ void Entry::addSpecialListItem(const char *listName,int itemId)
 
 EntryNav::EntryNav(EntryNav *parent, Entry *e)
              : m_parent(parent), m_subList(0), m_section(e->section), m_type(e->type),
-              m_name(e->name), m_fileDef(0), m_info(0), m_offset(-1), 
-              m_noLoad(FALSE)
+              m_name(e->name), m_fileDef(0), m_lang(e->lang), 
+              m_info(0), m_offset(-1), m_noLoad(FALSE) 
 {
   if (e->tagInfo)
   {
