@@ -3,7 +3,7 @@
  * $Id: $
  *
  *
- * Copyright (C) 1997-2010 by Dimitri van Heesch.
+ * Copyright (C) 1997-2011 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -142,6 +142,7 @@ HtmlDocVisitor::HtmlDocVisitor(FTextStream &t,CodeOutputInterface &ci,
 
 void HtmlDocVisitor::visit(DocWord *w)
 {
+  //printf("word: %s\n",w->word().data());
   if (m_hide) return;
   filter(w->word());
 }
@@ -179,6 +180,7 @@ void HtmlDocVisitor::visit(DocSymbol *s)
     case DocSymbol::Amp:     m_t << "&amp;"; break;
     case DocSymbol::Dollar:  m_t << "$"; break;
     case DocSymbol::Hash:    m_t << "#"; break;
+    case DocSymbol::DoubleColon: m_t << "::"; break;
     case DocSymbol::Percent: m_t << "%"; break;
     case DocSymbol::Copy:    m_t << "&copy;"; break;
     case DocSymbol::Tm:      m_t << "&trade;"; break;
@@ -200,7 +202,7 @@ void HtmlDocVisitor::visit(DocSymbol *s)
     case DocSymbol::Szlig:   m_t << "&szlig;"; break;
     case DocSymbol::Cedil:   m_t << "&" << s->letter() << "cedil;"; break;
     case DocSymbol::Ring:    m_t << "&" << s->letter() << "ring;"; break;
-    case DocSymbol::Nbsp:    m_t << "&nbsp;"; break;
+    case DocSymbol::Nbsp:    m_t << "&#160;"; break;
     case DocSymbol::AElig:   m_t << "&AElig;"; break;
     case DocSymbol::Aelig:   m_t << "&aelig;"; break;
     default:
@@ -304,7 +306,7 @@ void HtmlDocVisitor::visit(DocVerbatim *s)
   if (m_hide) return;
   switch(s->type())
   {
-    case DocVerbatim::Code: // fall though
+    case DocVerbatim::Code: 
       forceEndParagraph(s);
       m_t << PREFRAG_START;
       Doxygen::parserManager->getParser(m_langExt)
@@ -378,7 +380,7 @@ void HtmlDocVisitor::visit(DocVerbatim *s)
 
         forceEndParagraph(s);
         m_t << "<div align=\"center\">" << endl;
-        writeMscFile(baseName,s->relPath(),s->context());
+        writeMscFile(baseName+".msc",s->relPath(),s->context());
         m_t << "</div>" << endl;
         forceStartParagraph(s);
 
@@ -490,14 +492,36 @@ void HtmlDocVisitor::visit(DocFormula *f)
     forceEndParagraph(f);
     m_t << "<p class=\"formulaDsp\">" << endl;
   }
-  m_t << "<img class=\"formula" 
+
+  if (Config_getBool("USE_MATHJAX"))
+  {
+    QCString text = f->text();
+    bool closeInline = FALSE;
+    if (!bDisplay && !text.isEmpty() && text.at(0)=='$' && 
+                      text.at(text.length()-1)=='$')
+    {
+      closeInline=TRUE;
+      text = text.mid(1,text.length()-2);
+      m_t << "\\(";
+    }
+    m_t << convertToHtml(text);
+    if (closeInline)
+    {
+      m_t << "\\)";
+    }
+  }
+  else
+  {
+    m_t << "<img class=\"formula" 
       << (bDisplay ? "Dsp" : "Inl");
-  m_t << "\" alt=\"";
-  filterQuotedCdataAttr(f->text());
-  m_t << "\"";
-  /// @todo cache image dimensions on formula generation and give height/width
-  /// for faster preloading and better rendering of the page
-  m_t << " src=\"" << f->relPath() << f->name() << ".png\"/>";
+    m_t << "\" alt=\"";
+    filterQuotedCdataAttr(f->text());
+    m_t << "\"";
+    /// @todo cache image dimensions on formula generation and give height/width
+    /// for faster preloading and better rendering of the page
+    m_t << " src=\"" << f->relPath() << f->name() << ".png\"/>";
+
+  }
   if (bDisplay)
   {
     m_t << endl << "</p>" << endl;
@@ -518,7 +542,7 @@ void HtmlDocVisitor::visit(DocIndexEntry *e)
   //       e->scope()  ? e->scope()->name().data()  : "<null>",
   //       e->member() ? e->member()->name().data() : "<null>"
   //      );
-  Doxygen::indexList.addIndexItem(e->scope(),e->member(),anchor,e->entry());
+  Doxygen::indexList.addIndexItem(e->scope(),e->member(),e->entry());
 }
 
 void HtmlDocVisitor::visit(DocSimpleSectSep *)
@@ -534,6 +558,7 @@ void HtmlDocVisitor::visit(DocSimpleSectSep *)
 
 void HtmlDocVisitor::visitPre(DocAutoList *l)
 {
+  //printf("DocAutoList::visitPre\n");
   if (m_hide) return;
   forceEndParagraph(l);
   if (l->isEnumList())
@@ -557,6 +582,7 @@ void HtmlDocVisitor::visitPre(DocAutoList *l)
 
 void HtmlDocVisitor::visitPost(DocAutoList *l)
 {
+  //printf("DocAutoList::visitPost\n");
   if (m_hide) return;
   if (l->isEnumList())
   {
@@ -638,14 +664,17 @@ static int getParagraphContext(DocPara *p,bool &isFirst,bool &isLast)
       case DocNode::Kind_AutoListItem:
         isFirst=TRUE;
         isLast =TRUE;
-        if (isFirst) t=1;
-        if (isLast)  t=3;
+        t=1; // not used
         break;
       case DocNode::Kind_SimpleListItem:
         isFirst=TRUE;
         isLast =TRUE;
-        if (isFirst) t=1;
-        if (isLast)  t=3;
+        t=1; // not used
+        break;
+      case DocNode::Kind_ParamList:
+        isFirst=TRUE;
+        isLast =TRUE;
+        t=1; // not used
         break;
       case DocNode::Kind_HtmlListItem:
         isFirst=isFirstChildNode((DocHtmlListItem*)p->parent(),p);
@@ -703,7 +732,7 @@ void HtmlDocVisitor::visitPre(DocPara *p)
 {
   if (m_hide) return;
 
-  //printf("Processing docpara with parent of kind %d\n",
+  //printf("DocPara::visitPre: parent of kind %d ",
   //       p->parent() ? p->parent()->kind() : -1);
 
   bool needsTag = FALSE;
@@ -771,6 +800,7 @@ void HtmlDocVisitor::visitPre(DocPara *p)
   //printf("startPara first=%d last=%d\n",isFirst,isLast);
   if (isFirst && isLast) needsTag=FALSE;
 
+  //printf("  needsTag=%d\n",needsTag);
   // write the paragraph tag (if needed)
   if (needsTag) m_t << "<p" << contexts[t] << ">";
 }
@@ -839,6 +869,8 @@ void HtmlDocVisitor::visitPost(DocPara *p)
   //printf("endPara first=%d last=%d\n",isFirst,isLast);
   if (isFirst && isLast) needsTag=FALSE;
 
+  //printf("DocPara::visitPost needsTag=%d\n",needsTag);
+
   if (needsTag) m_t << "</p>\n";
 
 }
@@ -1117,17 +1149,17 @@ void HtmlDocVisitor::visitPost(DocHtmlCaption *)
   m_t << "</caption>\n";
 }
 
-void HtmlDocVisitor::visitPre(DocInternal *i)
+void HtmlDocVisitor::visitPre(DocInternal *)
 {
   if (m_hide) return;
-  forceEndParagraph(i);
-  m_t << "<p><b>" << theTranslator->trForInternalUseOnly() << "</b></p>" << endl;
+  //forceEndParagraph(i);
+  //m_t << "<p><b>" << theTranslator->trForInternalUseOnly() << "</b></p>" << endl;
 }
 
-void HtmlDocVisitor::visitPost(DocInternal *i) 
+void HtmlDocVisitor::visitPost(DocInternal *) 
 {
   if (m_hide) return;
-  forceStartParagraph(i);
+  //forceStartParagraph(i);
 }
 
 void HtmlDocVisitor::visitPre(DocHRef *href)
@@ -1170,12 +1202,13 @@ void HtmlDocVisitor::visitPre(DocImage *img)
     {
       baseName=baseName.right(baseName.length()-i-1);
     }
-    m_t << "<div align=\"center\">" << endl;
+    m_t << "<div class=\"image\">" << endl;
     m_t << "<img src=\"" << img->relPath() << img->name() << "\" alt=\"" 
-      << baseName << "\"" << "/>" << endl;
+        << baseName << "\"" << htmlAttribsToString(img->attribs()) 
+        << "/>" << endl;
     if (img->hasCaption())
     {
-      m_t << "<p><strong>";
+      m_t << "<div class=\"caption\">" << endl;
     }
   }
   else // other format -> skip
@@ -1192,7 +1225,7 @@ void HtmlDocVisitor::visitPost(DocImage *img)
     if (m_hide) return;
     if (img->hasCaption())
     {
-      m_t << "</strong></p>";
+      m_t << "</div>";
     }
     m_t << "</div>" << endl;
     forceStartParagraph(img);
@@ -1206,11 +1239,11 @@ void HtmlDocVisitor::visitPost(DocImage *img)
 void HtmlDocVisitor::visitPre(DocDotFile *df)
 {
   if (m_hide) return;
+  m_t << "<div class=\"dotgraph\">" << endl;
   writeDotFile(df->file(),df->relPath(),df->context());
-  m_t << "<div align=\"center\">" << endl;
   if (df->hasCaption())
   { 
-    m_t << "<p><strong>";
+    m_t << "<div class=\"caption\">" << endl;
   }
 }
 
@@ -1219,7 +1252,27 @@ void HtmlDocVisitor::visitPost(DocDotFile *df)
   if (m_hide) return;
   if (df->hasCaption())
   {
-    m_t << "</strong></p>" << endl;
+    m_t << "</div>" << endl;
+  }
+  m_t << "</div>" << endl;
+}
+
+void HtmlDocVisitor::visitPre(DocMscFile *df)
+{
+  if (m_hide) return;
+  m_t << "<div class=\"mscgraph\">" << endl;
+  writeMscFile(df->file(),df->relPath(),df->context());
+  if (df->hasCaption())
+  { 
+    m_t << "<div class=\"caption\">" << endl;
+  }
+}
+void HtmlDocVisitor::visitPost(DocMscFile *df) 
+{
+  if (m_hide) return;
+  if (df->hasCaption())
+  {
+    m_t << "</div>" << endl;
   }
   m_t << "</div>" << endl;
 }
@@ -1312,25 +1365,33 @@ void HtmlDocVisitor::visitPre(DocParamSect *s)
   if (m_hide) return;
   forceEndParagraph(s);
   m_t << "<dl><dt><b>";
+  QCString className;
   switch(s->type())
   {
     case DocParamSect::Param: 
-      m_t << theTranslator->trParameters(); break;
+      m_t << theTranslator->trParameters(); 
+      className="params";
+      break;
     case DocParamSect::RetVal: 
-      m_t << theTranslator->trReturnValues(); break;
+      m_t << theTranslator->trReturnValues(); 
+      className="retval";
+      break;
     case DocParamSect::Exception: 
-      m_t << theTranslator->trExceptions(); break;
+      m_t << theTranslator->trExceptions(); 
+      className="exception";
+      break;
     case DocParamSect::TemplateParam: 
       /* TODO: add this 
       m_t << theTranslator->trTemplateParam(); break;
       */
       m_t << "Template Parameters"; break;
+      className="tparams";
     default:
       ASSERT(0);
   }
   m_t << ":";
   m_t << "</b></dt><dd>" << endl;
-  m_t << "  <table border=\"0\" cellspacing=\"2\" cellpadding=\"0\">" << endl;
+  m_t << "  <table class=\"" << className << "\">" << endl;
 }
 
 void HtmlDocVisitor::visitPost(DocParamSect *s)
@@ -1344,26 +1405,57 @@ void HtmlDocVisitor::visitPost(DocParamSect *s)
 
 void HtmlDocVisitor::visitPre(DocParamList *pl)
 {
+  //printf("DocParamList::visitPre\n");
   if (m_hide) return;
-  m_t << "    <tr><td valign=\"top\">";
-  if (pl->direction()!=DocParamSect::Unspecified)
+  m_t << "    <tr>";
+  DocParamSect *sect = 0;
+  if (pl->parent()->kind()==DocNode::Kind_ParamSect)
   {
-    m_t << "<tt>[";
-    if (pl->direction()==DocParamSect::In)
-    {
-      m_t << "in";
-    }
-    else if (pl->direction()==DocParamSect::Out)
-    {
-      m_t << "out";
-    }
-    else if (pl->direction()==DocParamSect::InOut)
-    {
-      m_t << "in,out";
-    }
-    m_t << "]</tt>&nbsp;";
+    sect=(DocParamSect*)pl->parent();
   }
-  m_t << "</td><td valign=\"top\"><em>";
+  if (sect && sect->hasInOutSpecifier())
+  {
+    m_t << "<td class=\"paramdir\">";
+    if (pl->direction()!=DocParamSect::Unspecified)
+    {
+      m_t << "[";
+      if (pl->direction()==DocParamSect::In)
+      {
+        m_t << "in";
+      }
+      else if (pl->direction()==DocParamSect::Out)
+      {
+        m_t << "out";
+      }
+      else if (pl->direction()==DocParamSect::InOut)
+      {
+        m_t << "in,out";
+      }
+      m_t << "]";
+    }
+    m_t << "</td>";
+  }
+  if (sect && sect->hasTypeSpecifier())
+  {
+    m_t << "<td class=\"paramtype\">";
+    QListIterator<DocNode> li(pl->paramTypes());
+    DocNode *type;
+    bool first=TRUE;
+    for (li.toFirst();(type=li.current());++li)
+    {
+      if (!first) m_t << "&#160;|&#160;"; else first=FALSE;
+      if (type->kind()==DocNode::Kind_Word)
+      {
+        visit((DocWord*)type); 
+      }
+      else if (type->kind()==DocNode::Kind_LinkedWord)
+      {
+        visit((DocLinkedWord*)type); 
+      }
+    }
+    m_t << "</td>";
+  }
+  m_t << "<td class=\"paramname\">";
   //QStrListIterator li(pl->parameters());
   //const char *s;
   QListIterator<DocNode> li(pl->parameters());
@@ -1381,11 +1473,12 @@ void HtmlDocVisitor::visitPre(DocParamList *pl)
       visit((DocLinkedWord*)param); 
     }
   }
-  m_t << "</em>&nbsp;</td><td>";
+  m_t << "</td><td>";
 }
 
 void HtmlDocVisitor::visitPost(DocParamList *)
 {
+  //printf("DocParamList::visitPost\n");
   if (m_hide) return;
   m_t << "</td></tr>" << endl;
 }
@@ -1551,15 +1644,14 @@ void HtmlDocVisitor::writeDotFile(const QCString &fn,const QCString &relPath,
   {
     baseName=baseName.right(baseName.length()-i-1);
   }
+  if ((i=baseName.find('.'))!=-1) // strip extension
+  {
+    baseName=baseName.left(i);
+  }
+  baseName.prepend("dot_");
   QCString outDir = Config_getString("HTML_OUTPUT");
   writeDotGraphFromFile(fn,outDir,baseName,BITMAP);
-  QCString mapName = baseName+".map";
-  QCString mapFile = fn+".map";
-  m_t << "<img src=\"" << relPath << baseName << "." 
-      << Config_getEnum("DOT_IMAGE_FORMAT") << "\" alt=\""
-      << baseName << "\" border=\"0\" usemap=\"#" << mapName << "\">" << endl;
-  QCString imap = getDotImageMapFromFile(baseName,outDir,relPath,context);
-  m_t << "<map name=\"" << mapName << "\" id=\"" << mapName << "\">" << imap << "</map>" << endl;
+  writeDotImageMapFromFile(m_t,fn,outDir,relPath,baseName,context);
 }
 
 void HtmlDocVisitor::writeMscFile(const QCString &fileName,const QCString &relPath,
@@ -1567,18 +1659,18 @@ void HtmlDocVisitor::writeMscFile(const QCString &fileName,const QCString &relPa
 {
   QCString baseName=fileName;
   int i;
-  if ((i=baseName.findRev('/'))!=-1)
+  if ((i=baseName.findRev('/'))!=-1) // strip path
   {
     baseName=baseName.right(baseName.length()-i-1);
   }
+  if ((i=baseName.find('.'))!=-1) // strip extension
+  {
+    baseName=baseName.left(i);
+  }
+  baseName.prepend("msc_");
   QCString outDir = Config_getString("HTML_OUTPUT");
   writeMscGraphFromFile(fileName,outDir,baseName,MSC_BITMAP);
-  QCString mapName = baseName+".map";
-  QCString mapFile = fileName+".map";
-  m_t << "<img src=\"" << relPath << baseName << ".png\" alt=\""
-    << baseName << "\" border=\"0\" usemap=\"#" << mapName << "\">" << endl;
-  QCString imap = getMscImageMapFromFile(fileName,outDir,relPath,context);
-  m_t << "<map name=\"" << mapName << "\" id=\"" << mapName << "\">" << imap << "</map>" << endl;
+  writeMscImageMapFromFile(m_t,fileName,outDir,relPath,baseName,context);
 }
 
 /** Used for items found inside a paragraph, which due to XHTML restrictions
