@@ -2,7 +2,7 @@
  *
  * 
  *
- * Copyright (C) 1997-2010 by Dimitri van Heesch.
+ * Copyright (C) 1997-2011 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -447,7 +447,7 @@ void HtmlHelp::createProjectFile()
     FTextStream t(&f);
     
     QCString indexName="index"+Doxygen::htmlFileExtension;
-    if (Config_getBool("GENERATE_TREEVIEW")) indexName="main"+Doxygen::htmlFileExtension;
+    //if (Config_getBool("GENERATE_TREEVIEW")) indexName="main"+Doxygen::htmlFileExtension;
     t << "[OPTIONS]\n";
     if (!Config_getString("CHM_FILE").isEmpty())
     {
@@ -483,6 +483,8 @@ void HtmlHelp::createProjectFile()
       t << s << endl;
       s = indexFiles.next();
     }
+#if 0
+    // items not found by the html help compiler scan.
     t << "tabs.css" << endl;
     t << "tab_a.png" << endl;
     t << "tab_b.png" << endl;
@@ -490,10 +492,47 @@ void HtmlHelp::createProjectFile()
     t << "tab_s.png" << endl;
     t << "nav_h.png" << endl;
     t << "nav_f.png" << endl;
+    t << "bc_s.png" << endl;
     if (Config_getBool("HTML_DYNAMIC_SECTIONS"))
     {
-      t << "open.gif" << endl;
-      t << "closed.gif" << endl;
+      t << "open.png" << endl;
+      t << "closed.png" << endl;
+    }
+    if (Config_getBool("GENERATE_HTMLHELP"))
+    {
+      t << "ftv2blank.png" << endl;
+      t << "ftv2doc.png" << endl;
+      t << "ftv2folderclosed.png" << endl;
+      t << "ftv2folderopen.png" << endl;
+      t << "ftv2lastnode.png" << endl;
+      t << "ftv2link.png" << endl;
+      t << "ftv2mlastnode.png" << endl;
+      t << "ftv2mnode.png" << endl;
+      t << "ftv2node.png" << endl;
+      t << "ftv2plastnode.png" << endl;
+      t << "ftv2pnode.png" << endl;
+      t << "ftv2vertline.png" << endl;
+    }
+    if (Config_getBool("SEARCHENGINE"))
+    {
+      t << "search_l.png" << endl;
+      t << "search_m.png" << endl;
+      t << "search_r.png" << endl;
+      if (Config_getBool("SERVER_BASED_SEARCH"))
+      {
+        t << "mag.png" << endl;
+      }
+      else
+      {
+        t << "mag_sel.png" << endl;
+        t << "close.png" << endl;
+      }
+    }
+#endif
+    uint i;
+    for (i=0;i<imageFiles.count();i++)
+    {
+      t << imageFiles.at(i) << endl;
     }
     f.close();
   }
@@ -627,7 +666,7 @@ void HtmlHelp::addContentsItem(bool isDir,
 
 
 void HtmlHelp::addIndexItem(Definition *context,MemberDef *md,
-                            const char *anc,const char *word)
+                            const char *word)
 {
   if (md)
   {
@@ -647,14 +686,19 @@ void HtmlHelp::addIndexItem(Definition *context,MemberDef *md,
     QCString level2  = md->name();
     QCString contRef = separateMemberPages ? cfname : cfiname;
     QCString memRef  = cfname;
-    QCString anchor  = anc;
+    QCString anchor  = md->anchor();
     index->addItem(level1,level2,contRef,anchor,TRUE,FALSE);
     index->addItem(level2,level1,memRef,anchor,TRUE,TRUE);
   }
   else if (context)
   {
     QCString level1  = word ? QCString(word) : context->name();
-    index->addItem(level1,0,context->getOutputFileBase(),anc,TRUE,FALSE);
+    index->addItem(level1,0,context->getOutputFileBase(),0,TRUE,FALSE);
   }
 }
 
+void HtmlHelp::addImageFile(const char *fileName)
+{
+  imageFiles.append(fileName);
+}
+
