@@ -2,7 +2,7 @@
  *
  * $Id: index.h,v 1.28 2001/03/19 19:27:40 root Exp $
  *
- * Copyright (C) 1997-2008 by Dimitri van Heesch.
+ * Copyright (C) 1997-2011 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -22,11 +22,12 @@
 #include <qfile.h>
 #include <qlist.h>
 
+class Definition;
 class MemberDef;
 class OutputList;
-class QTextStream;
-
+class FTextStream;
 
+/** \brief Abstract interface for index generators. */
 class IndexIntf
 {
   public:
@@ -37,44 +38,62 @@ class IndexIntf
     virtual void decContentsDepth() = 0;
     virtual void addContentsItem(bool isDir, const char *name, const char *ref = 0, 
                                  const char *file = 0, const char *anchor = 0) = 0;
-    virtual void addIndexItem(const char *level1, const char *level2, const char *contRef, 
-                              const char *memRef, const char *anchor,const MemberDef *md) = 0;
+    virtual void addIndexItem(Definition *context,MemberDef *md,const char *title) = 0;
     virtual void addIndexFile(const char *name) = 0;
     virtual void addImageFile(const char *name) = 0;
     virtual void addStyleSheetFile(const char *name) = 0;
 };
 
+/** \brief A list of index interfaces.
+ *
+ *  This class itself implements all methods of IndexIntf and
+ *  just forwards the calls to all items in the list.
+ */
 class IndexList : public IndexIntf
 {
   private:
     QList<IndexIntf> m_intfs;
 
+    // --- foreach implementations for various number of arguments
+
     void foreach(void (IndexIntf::*methodPtr)())
     {
       QListIterator<IndexIntf> li(m_intfs);
       for (li.toFirst();li.current();++li) (li.current()->*methodPtr)();
     }
+
     template<typename A1>
     void foreach(void (IndexIntf::*methodPtr)(A1),A1 a1)
     {
       QListIterator<IndexIntf> li(m_intfs);
       for (li.toFirst();li.current();++li) (li.current()->*methodPtr)(a1);
     }
+
+    template<typename A1,typename A2,typename A3>
+    void foreach(void (IndexIntf::*methodPtr)(A1,A2,A3),A1 a1,A2 a2,A3 a3)
+    {
+      QListIterator<IndexIntf> li(m_intfs);
+      for (li.toFirst();li.current();++li) (li.current()->*methodPtr)(a1,a2,a3);
+    }
+
+    template<typename A1,typename A2,typename A3,typename A4>
+    void foreach(void (IndexIntf::*methodPtr)(A1,A2,A3,A4),A1 a1,A2 a2,A3 a3,A4 a4)
+    {
+      QListIterator<IndexIntf> li(m_intfs);
+      for (li.toFirst();li.current();++li) (li.current()->*methodPtr)(a1,a2,a3,a4);
+    }
+
     template<typename A1,typename A2,typename A3,typename A4,typename A5>
     void foreach(void (IndexIntf::*methodPtr)(A1,A2,A3,A4,A5),A1 a1,A2 a2,A3 a3,A4 a4,A5 a5)
     {
       QListIterator<IndexIntf> li(m_intfs);
       for (li.toFirst();li.current();++li) (li.current()->*methodPtr)(a1,a2,a3,a4,a5);
     }
-    template<typename A1,typename A2,typename A3,typename A4,typename A5,typename A6>
-    void foreach(void (IndexIntf::*methodPtr)(A1,A2,A3,A4,A5,A6),A1 a1,A2 a2,A3 a3,A4 a4,A5 a5,A6 a6)
-    {
-      QListIterator<IndexIntf> li(m_intfs);
-      for (li.toFirst();li.current();++li) (li.current()->*methodPtr)(a1,a2,a3,a4,a5,a6);
-    }
 
   public:
+    /** Creates a list of indexes */
     IndexList() { m_intfs.setAutoDelete(TRUE); }
+    /** Add an index generator to the list */
     void addIndex(IndexIntf *intf) 
     { m_intfs.append(intf); }
 
@@ -91,10 +110,9 @@ class IndexList : public IndexIntf
                          const char *file = 0, const char *anchor = 0)
     { foreach<bool,const char *,const char *,const char *,const char*>
              (&IndexIntf::addContentsItem,isDir,name,ref,file,anchor); }
-    void addIndexItem(const char *level1, const char *level2, const char *contRef, 
-                      const char *memRef, const char *anchor,const MemberDef *md)
-    { foreach<const char *,const char *,const char *,const char *,const char *,const MemberDef *>
-             (&IndexIntf::addIndexItem,level1,level2,contRef,memRef,anchor,md); }
+    void addIndexItem(Definition *context,MemberDef *md,const char *title=0)
+    { foreach<Definition *,MemberDef *>
+             (&IndexIntf::addIndexItem,context,md,title); }
     void addIndexFile(const char *name) 
     { foreach<const char *>(&IndexIntf::addIndexFile,name); }
     void addImageFile(const char *name) 
@@ -185,7 +203,7 @@ enum NamespaceMemberHighlight
   NMHL_Typedefs,
   NMHL_Enums,
   NMHL_EnumValues,
-  NMHL_Total = FMHL_EnumValues+1
+  NMHL_Total = NMHL_EnumValues+1
 };
 
 enum ClassHighlight
@@ -239,12 +257,12 @@ extern int documentedHtmlFiles;
 extern int documentedPages;
 extern int documentedDirs;
 
-void startTitle(OutputList &ol,const char *fileName);
+void startTitle(OutputList &ol,const char *fileName,Definition *def=0);
 void endTitle(OutputList &ol,const char *fileName,const char *name);
 void startFile(OutputList &ol,const char *name,const char *manName,
                const char *title,HighlightedItem hli=HLI_None,
-               bool additionalIndices=FALSE);
-void endFile(OutputList &ol,bool external=FALSE);
+               bool additionalIndices=FALSE,const char *altSidebarName=0);
+void endFile(OutputList &ol,bool skipNavIndex=FALSE);
 
 void initClassMemberIndices();
 void initFileMemberIndices();
@@ -254,7 +272,7 @@ void addFileMemberNameToIndex(MemberDef *md);
 void addNamespaceMemberNameToIndex(MemberDef *md);
 
 // search engine
-void writeSearchIndex();
-void writeSearchCategories(QTextStream &t);
+void writeJavascriptSearchIndex();
+void writeSearchCategories(FTextStream &t);
 
 #endif
