@@ -2,7 +2,7 @@
  *
  * 
  *
- * Copyright (C) 1997-2010 by Dimitri van Heesch.
+ * Copyright (C) 1997-2011 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -205,7 +205,7 @@ bool setTranslator(const char *langName)
 #ifdef LANG_DE
   else if (L_EQUAL("german"))
   {
-    theTranslator=new TranslatorDecoder(new TranslatorGerman);
+    theTranslator=new TranslatorGerman;
   }
 #endif
 #ifdef LANG_JP
@@ -223,7 +223,7 @@ bool setTranslator(const char *langName)
 #ifdef LANG_ES
   else if (L_EQUAL("spanish"))
   {
-    theTranslator=new TranslatorDecoder(new TranslatorSpanish);
+    theTranslator=new TranslatorSpanish;
   }
 #endif
 #ifdef LANG_FI
@@ -241,13 +241,13 @@ bool setTranslator(const char *langName)
 #ifdef LANG_HR
   else if (L_EQUAL("croatian"))
   {
-    theTranslator=new TranslatorDecoder(new TranslatorCroatian);
+    theTranslator=new TranslatorCroatian;
   }
 #endif
 #ifdef LANG_PL
   else if (L_EQUAL("polish"))
   {
-    theTranslator=new TranslatorDecoder(new TranslatorPolish);
+    theTranslator=new TranslatorPolish;
   }
 #endif
 #ifdef LANG_PT
@@ -307,7 +307,7 @@ bool setTranslator(const char *langName)
 #ifdef LANG_BR
   else if (L_EQUAL("brazilian"))
   {
-    theTranslator=new TranslatorDecoder(new TranslatorBrazilian);
+    theTranslator=new TranslatorBrazilian;
   }
 #endif
 #ifdef LANG_DK
@@ -319,7 +319,7 @@ bool setTranslator(const char *langName)
 #ifdef LANG_SK
   else if (L_EQUAL("slovak"))
   {
-    theTranslator=new TranslatorDecoder(new TranslatorSlovak);
+    theTranslator=new TranslatorSlovak;
   }
 #endif
 #ifdef LANG_UA
@@ -331,7 +331,7 @@ bool setTranslator(const char *langName)
 #ifdef LANG_GR
   else if (L_EQUAL("greek"))
   {
-    theTranslator=new TranslatorDecoder(new TranslatorGreek);
+    theTranslator=new TranslatorGreek;
   }
 #endif
 #ifdef LANG_SR
@@ -373,7 +373,7 @@ bool setTranslator(const char *langName)
 #ifdef LANG_FA
   else if (L_EQUAL("persian") || L_EQUAL("farsi"))
   {
-    theTranslator=new TranslatorDecoder(new TranslatorPersian);
+    theTranslator=new TranslatorPersian;
   }
 #endif
 #ifdef LANG_MK
@@ -408,6 +408,6 @@ bool setTranslator(const char *langName)
   }
   
   QCString msg = theTranslator->updateNeededMessage();
-  if (!msg.isEmpty()) warn_cont(msg);
+  if (!msg.isEmpty()) err(msg);
   return TRUE;
 }
