@@ -3,7 +3,7 @@
  * $Id: $
  *
  *
- * Copyright (C) 1997-2010 by Dimitri van Heesch.
+ * Copyright (C) 1997-2011 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -106,6 +106,8 @@ class LatexDocVisitor : public DocVisitor
     void visitPost(DocImage *);
     void visitPre(DocDotFile *);
     void visitPost(DocDotFile *);
+    void visitPre(DocMscFile *);
+    void visitPost(DocMscFile *);
     void visitPre(DocLink *lnk);
     void visitPost(DocLink *);
     void visitPre(DocRef *ref);
@@ -144,6 +146,10 @@ class LatexDocVisitor : public DocVisitor
     void startDotFile(const QCString &fileName,const QCString &width,
                       const QCString &height, bool hasCaption);
     void endDotFile(bool hasCaption);
+
+    void startMscFile(const QCString &fileName,const QCString &width,
+                      const QCString &height, bool hasCaption);
+    void endMscFile(bool hasCaption);
     void writeMscFile(const QCString &fileName);
 
     void pushEnabled();
