@@ -2,7 +2,7 @@
  *
  * $Id: htmlgen.cpp,v 1.17 1998/11/28 11:33:19 root Exp $
  *
- * Copyright (C) 1997-2008 by Dimitri van Heesch.
+ * Copyright (C) 1997-2011 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -100,6 +100,7 @@ void ManGenerator::init()
 static QCString buildFileName(const char *name)
 {
   QCString fileName;
+  if (name==0) return "noname";
 
   const char *p=name;
   char c;
@@ -238,7 +239,7 @@ void ManGenerator::endHtmlLink()
 //  docify(url);
 //}
 
-void ManGenerator::startGroupHeader()
+void ManGenerator::startGroupHeader(int)
 {
   if (!firstCol) t << endl;
   t << ".SH \"";
@@ -246,7 +247,7 @@ void ManGenerator::startGroupHeader()
   firstCol=FALSE;
 }
 
-void ManGenerator::endGroupHeader()
+void ManGenerator::endGroupHeader(int)
 {
   t << "\"\n.PP " << endl;
   firstCol=TRUE;
@@ -254,7 +255,7 @@ void ManGenerator::endGroupHeader()
   upperCase=FALSE;
 }
 
-void ManGenerator::startMemberHeader()
+void ManGenerator::startMemberHeader(const char *)
 {
   if (!firstCol) t << endl;
   t << ".SS \"";
@@ -386,7 +387,7 @@ void ManGenerator::endCodeFragment()
   col=0;
 }
 
-void ManGenerator::startMemberDoc(const char *,const char *,const char *,const char *) 
+void ManGenerator::startMemberDoc(const char *,const char *,const char *,const char *,bool) 
 { 
   if (!firstCol) t << endl;
   t << ".SS \""; 
@@ -407,8 +408,11 @@ void ManGenerator::startDoxyAnchor(const char *,const char *manName,
     // the name of the link file is derived from the name of the anchor:
     // - truncate after an (optional) ::
     QCString baseName = name;
-    int i=baseName.findRev(':');
-    if (i!=-1) baseName=baseName.right(baseName.length()-i-1);
+    int i=baseName.findRev("::");
+    if (i!=-1) baseName=baseName.right(baseName.length()-i-2);
+
+    //printf("Converting man link '%s'->'%s'->'%s'\n",
+    //       name,baseName.data(),buildFileName(baseName).data());
     
     // - remove dangerous characters and append suffix, then add dir prefix
     QCString fileName=dir+"/"+buildFileName( baseName );
@@ -418,9 +422,9 @@ void ManGenerator::startDoxyAnchor(const char *,const char *manName,
     {
 	if ( linkfile.open( IO_WriteOnly ) ) 
         {
-	      QTextStream linkstream;
+	      FTextStream linkstream;
 	      linkstream.setDevice(&linkfile);
-	      linkstream.setEncoding(QTextStream::UnicodeUTF8);
+	      //linkstream.setEncoding(QTextStream::UnicodeUTF8);
 	      linkstream << ".so man" << getExtension() << "/" << buildFileName( manName ) << endl;
 	}
     }
@@ -582,11 +586,11 @@ void ManGenerator::startSection(const char *,const char *,SectionInfo::SectionTy
   {
     switch(type)
     {
-      case SectionInfo::Page:          startGroupHeader(); break;
-      case SectionInfo::Section:       startGroupHeader(); break;
-      case SectionInfo::Subsection:    startMemberHeader(); break;
-      case SectionInfo::Subsubsection: startMemberHeader(); break;
-      case SectionInfo::Paragraph:     startMemberHeader(); break;
+      case SectionInfo::Page:          startGroupHeader(FALSE); break;
+      case SectionInfo::Section:       startGroupHeader(FALSE); break;
+      case SectionInfo::Subsection:    startMemberHeader(0); break;
+      case SectionInfo::Subsubsection: startMemberHeader(0); break;
+      case SectionInfo::Paragraph:     startMemberHeader(0); break;
       default: ASSERT(0); break;
     }
   }
@@ -598,8 +602,8 @@ void ManGenerator::endSection(const char *,SectionInfo::SectionType type)
   {
     switch(type)
     {
-      case SectionInfo::Page:          endGroupHeader(); break;
-      case SectionInfo::Section:       endGroupHeader(); break;
+      case SectionInfo::Page:          endGroupHeader(0); break;
+      case SectionInfo::Section:       endGroupHeader(0); break;
       case SectionInfo::Subsection:    endMemberHeader(); break;
       case SectionInfo::Subsubsection: endMemberHeader(); break;
       case SectionInfo::Paragraph:     endMemberHeader(); break;
@@ -711,5 +715,28 @@ void ManGenerator::endConstraintList()
 {
 }
 
+void ManGenerator::startInlineDescription() 
+{
+}
+
+void ManGenerator::endInlineDescription() 
+{
+}
+
+void ManGenerator::startInlineHeader() 
+{
+  if (!firstCol) 
+  {
+    t << endl << ".PP" << endl << ".in -1c" << endl;
+  }
+  t << ".RI \"\\fB"; 
+}
+
+void ManGenerator::endInlineHeader() 
+{
+  t << "\\fP\"" << endl << ".in +1c" << endl;
+  firstCol = FALSE;
+}
+
 
 
