@@ -2,7 +2,7 @@
  *
  * 
  *
- * Copyright (C) 1997-2008 by Dimitri van Heesch.
+ * Copyright (C) 1997-2011 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -330,6 +330,10 @@ class MemberDef : public Definition
     void copyArgumentNames(MemberDef *bmd);
 
     void setCategory(ClassDef *);
+
+    void setDocumentation(const char *d,const char *docFile,int docLine,bool stripWhiteSpace=TRUE);
+    void setBriefDescription(const char *b,const char *briefFile,int briefLine);
+    void setInbodyDocumentation(const char *d,const char *inbodyFile,int inbodyLine);
     
     //-----------------------------------------------------------------------------------
     // --- actions ----
@@ -341,7 +345,8 @@ class MemberDef : public Definition
                    bool inGroup); 
     void writeDocumentation(MemberList *ml,OutputList &ol,
                             const char *scopeName,Definition *container,
-                            bool inGroup,bool showEnumValues=FALSE);
+                            bool inGroup,bool showEnumValues=FALSE,bool
+                            showInline=FALSE);
     void warnIfUndocumented();
     
     MemberDef *createTemplateInstanceMember(ArgumentList *formalArgs,
@@ -362,6 +367,9 @@ class MemberDef : public Definition
     void unlock() const;
     void saveToDisk() const;
     void makeResident() const;
+    void _computeLinkableInProject();
+    void _computeIsConstructor();
+    void _computeIsDestructor();
 
     static int s_indentLevel;
     // disable copying of member defs
@@ -376,6 +384,9 @@ class MemberDef : public Definition
     int m_cacheHandle;
     off_t m_storagePos;     // location where the item is stored in file (if impl==0)
     bool m_flushPending;
+    uchar m_isLinkableCached;    // 0 = not cached, 1=FALSE, 2=TRUE
+    uchar m_isConstructorCached; // 0 = not cached, 1=FALSE, 2=TRUE
+    uchar m_isDestructorCached;  // 0 = not cached, 1=FALSE, 2=TRUE
 };
 
 #endif
