@@ -2,7 +2,7 @@
  *
  * $Id: msc.cpp,v 1.14 2001/03/19 19:27:40 root Exp $
  *
- * Copyright (C) 1997-2010 by Dimitri van Heesch.
+ * Copyright (C) 1997-2011 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -85,6 +85,7 @@ static bool convertMapFile(QTextStream &t,const char *mapName,const QCString rel
 
   return TRUE;
 }
+
 void writeMscGraphFromFile(const char *inFile,const char *outDir,
                            const char *outFile,MscOutputFormat format)
 {
@@ -112,11 +113,12 @@ void writeMscGraphFromFile(const char *inFile,const char *outDir,
   }
   mscArgs+=" -i \"";
   mscArgs+=inFile;
-  mscArgs+=".msc\" -o \"";
+ 
+  mscArgs+="\" -o \"";
   mscArgs+=outFile;
   mscArgs+=extension+"\"";
   int exitCode;
-  //printf("*** running: %s %s\n",mscExe.data(),mscArgs.data());
+//  printf("*** running: %s %s outDir:%s %s\n",mscExe.data(),mscArgs.data(),outDir,outFile);
   portable_sysTimerStart();
   if ((exitCode=portable_system(mscExe,mscArgs,FALSE))!=0)
   {
@@ -146,6 +148,8 @@ QCString getMscImageMapFromFile(const QCString& inFile, const QCString& outDir,
 {
   QCString outFile = inFile + ".map";
 
+
+  //printf("*** running:getMscImageMapFromFile \n");
   // chdir to the output dir, so dot can find the font file.
   QCString oldDir = convertToQCString(QDir::currentDirPath());
   // go to the html output directory (i.e. path)
@@ -154,7 +158,9 @@ QCString getMscImageMapFromFile(const QCString& inFile, const QCString& outDir,
 
   QCString mscExe = Config_getString("MSCGEN_PATH")+"mscgen"+portable_commandExtension();
   QCString mscArgs = "-T ismap -i \"";
-  mscArgs+=inFile + ".msc\" -o \"";
+  mscArgs+=inFile;
+  QFileInfo fi(inFile);
+  mscArgs+="\" -o \"";
   mscArgs+=outFile + "\"";
 
   int exitCode;
@@ -176,4 +182,17 @@ QCString getMscImageMapFromFile(const QCString& inFile, const QCString& outDir,
   return result.data();
 }
 
+void writeMscImageMapFromFile(FTextStream &t,const QCString &inFile,
+                              const QCString &outDir,
+                              const QCString &relPath,
+                              const QCString &baseName,
+                              const QCString &context)
+{
+  QCString mapName = baseName+".map";
+  QCString mapFile = inFile+".map";
+  t << "<img src=\"" << relPath << baseName << ".png\" alt=\""
+    << baseName << "\" border=\"0\" usemap=\"#" << mapName << "\">" << endl;
+  QCString imap = getMscImageMapFromFile(inFile,outDir,relPath,context);
+  t << "<map name=\"" << mapName << "\" id=\"" << mapName << "\">" << imap << "</map>" << endl;
+}
 
