@@ -2,7 +2,7 @@
  *
  * $Id: outputgen.h,v 1.48 2001/03/19 19:27:41 root Exp $
  *
- * Copyright (C) 1997-2007 by Dimitri van Heesch.
+ * Copyright (C) 1997-2011 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -19,7 +19,7 @@
 #define OUTPUTGEN_H
 
 #include "qtbc.h"
-#include <qtextstream.h>
+#include "ftextstream.h"
 #include <qbuffer.h>
 #include <qfile.h>
 #include <qstack.h>
@@ -101,7 +101,7 @@ class BaseOutputDocInterface : public CodeOutputInterface
                           const QCString &,bool)  {} 
     virtual void parseText(const QCString &)  {}
     
-    /*! Start of a bullet list: e.g. \c \<ul\> in html. writeListItem() is
+    /*! Start of a bullet list: e.g. \c \<ul\> in html. startItemListItem() is
      *  Used for the bullet items.
      */
     virtual void startItemList()  = 0;
@@ -109,7 +109,12 @@ class BaseOutputDocInterface : public CodeOutputInterface
     /*! Writes a list item for a bullet or enumerated 
      *  list: e.g. \c \<li\> in html 
      */
-    virtual void writeListItem()  = 0;
+    virtual void startItemListItem()  = 0;
+
+    /*! Writes a list item for a bullet or enumerated 
+     *  list: e.g. \c \</li\> in html 
+     */
+    virtual void endItemListItem()  = 0;
 
     /*! Ends a bullet list: e.g. \c \</ul\> in html */
     virtual void endItemList()    = 0;
@@ -130,11 +135,11 @@ class BaseOutputDocInterface : public CodeOutputInterface
     virtual void writeString(const char *text) = 0;
 
     /*! Starts a new paragraph */
-    virtual void newParagraph()   = 0;
+    //virtual void newParagraph()   = 0;
 
     /*! Starts a new paragraph */
     virtual void startParagraph() = 0;
-    /*! End a paragraph */
+    /*! Ends a paragraph */
     virtual void endParagraph() = 0;
 
     /*! Writes a link to an object in the documentation.
@@ -211,8 +216,11 @@ class BaseOutputDocInterface : public CodeOutputInterface
     /*! Starts an item of a description list: e.g. \c \<dt\> in HTML. */
     virtual void startDescItem() = 0;
 
+    virtual void startDescForItem() = 0;
+    virtual void endDescForItem() = 0;
+
     /*! Ends an item of a description list and starts the 
-     *  description itself: e.g. \c \<dd\> in HTML. 
+     *  description itself: e.g. \c \</dt\> in HTML. 
      */
     virtual void endDescItem() = 0;
 
@@ -227,7 +235,7 @@ class BaseOutputDocInterface : public CodeOutputInterface
     virtual void startParamList(ParamListTypes t,const char *title) = 0;
     virtual void endParamList() = 0;
 
-    virtual void writeDescItem() = 0;
+    //virtual void writeDescItem() = 0;
     virtual void startTitle() = 0;
     virtual void endTitle()   = 0;
 
@@ -235,7 +243,7 @@ class BaseOutputDocInterface : public CodeOutputInterface
     virtual void startSection(const char *,const char *,SectionInfo::SectionType) = 0;
     virtual void endSection(const char *,SectionInfo::SectionType) = 0;
 
-    virtual void lineBreak() = 0;
+    virtual void lineBreak(const char *style) = 0;
     virtual void addIndexItem(const char *s1,const char *s2) = 0;
 
     virtual void writeNonBreakableSpace(int) = 0;
@@ -279,12 +287,12 @@ class OutputGenerator : public BaseOutputDocInterface
     virtual OutputGenerator *get(OutputType o) = 0;
     void startPlainFile(const char *name);
     void endPlainFile();
-    QCString getContents() const;
+    //QCString getContents() const;
     bool isEnabled() const { return active; }
     void pushGeneratorState();
     void popGeneratorState();
-    void setEncoding(const QCString &enc) { encoding = enc; }
-    virtual void postProcess(QByteArray &) { }
+    //void setEncoding(const QCString &enc) { encoding = enc; }
+    //virtual void postProcess(QByteArray &) { }
 
     virtual void printDoc(DocNode *,const char *langExt) = 0;
 
@@ -297,11 +305,14 @@ class OutputGenerator : public BaseOutputDocInterface
     virtual void endFile() = 0;
     virtual void startIndexSection(IndexSections) = 0;
     virtual void endIndexSection(IndexSections) = 0;
+    virtual void writePageLink(const char *,bool) = 0;
     virtual void startProjectNumber() = 0;
     virtual void endProjectNumber() = 0;
     virtual void writeStyleInfo(int part) = 0;
     virtual void startTitleHead(const char *) = 0;
     virtual void endTitleHead(const char *fileName,const char *name) = 0;
+    virtual void startIndexListItem() = 0;
+    virtual void endIndexListItem()   = 0;
     virtual void startIndexList() = 0;
     virtual void endIndexList()   = 0;
     virtual void startIndexKey() = 0;
@@ -310,11 +321,13 @@ class OutputGenerator : public BaseOutputDocInterface
     virtual void endIndexValue(const char *,bool) = 0;
     virtual void startIndexItem(const char *ref,const char *file) = 0;
     virtual void endIndexItem(const char *ref,const char *file) = 0;
-    virtual void startGroupHeader() = 0;
-    virtual void endGroupHeader() = 0;
+    virtual void startGroupHeader(int) = 0;
+    virtual void endGroupHeader(int) = 0;
     virtual void startMemberSections() = 0;
     virtual void endMemberSections() = 0;
-    virtual void startMemberHeader() = 0;
+    virtual void startHeaderSection() = 0;
+    virtual void endHeaderSection() = 0;
+    virtual void startMemberHeader(const char *anchor) = 0;
     virtual void endMemberHeader() = 0;
     virtual void startMemberSubtitle() = 0;
     virtual void endMemberSubtitle() = 0;
@@ -322,6 +335,10 @@ class OutputGenerator : public BaseOutputDocInterface
     virtual void endMemberDocList() = 0;
     virtual void startMemberList() = 0;
     virtual void endMemberList() = 0;
+    virtual void startInlineDescription() = 0;
+    virtual void endInlineDescription() = 0;
+    virtual void startInlineHeader() = 0;
+    virtual void endInlineHeader() = 0;
     virtual void startAnonTypeScope(int) = 0;
     virtual void endAnonTypeScope(int) = 0;
     virtual void startMemberItem(int) = 0;
@@ -336,7 +353,7 @@ class OutputGenerator : public BaseOutputDocInterface
     virtual void endMemberGroup(bool) = 0;
     virtual void insertMemberAlign(bool) = 0;
     virtual void startMemberDoc(const char *,const char *,
-                                const char *,const char *) = 0;
+                                const char *,const char *,bool) = 0;
     virtual void endMemberDoc(bool) = 0;
     virtual void startDoxyAnchor(const char *fName,const char *manName,
                                  const char *anchor,const char *name,
@@ -352,21 +369,25 @@ class OutputGenerator : public BaseOutputDocInterface
     virtual void endIndent() = 0;
     virtual void writeSynopsis() = 0;
     virtual void startClassDiagram() = 0;
-    virtual void endClassDiagram(ClassDiagram &,const char *,const char *) = 0;
+    virtual void endClassDiagram(const ClassDiagram &,const char *,const char *) = 0;
     virtual void startDotGraph() = 0;
-    virtual void endDotGraph(DotClassGraph &g) = 0;
+    virtual void endDotGraph(const DotClassGraph &g) = 0;
     virtual void startInclDepGraph() = 0;
-    virtual void endInclDepGraph(DotInclDepGraph &g) = 0;
+    virtual void endInclDepGraph(const DotInclDepGraph &g) = 0;
     virtual void startGroupCollaboration() = 0;
-    virtual void endGroupCollaboration(DotGroupCollaboration &g) = 0;
+    virtual void endGroupCollaboration(const DotGroupCollaboration &g) = 0;
     virtual void startCallGraph() = 0;
-    virtual void endCallGraph(DotCallGraph &g) = 0;
+    virtual void endCallGraph(const DotCallGraph &g) = 0;
     virtual void startDirDepGraph() = 0;
-    virtual void endDirDepGraph(DotDirDeps &g) = 0;
-    virtual void writeGraphicalHierarchy(DotGfxHierarchyTable &g) = 0;
-    //virtual void startQuickIndexItem(const char *s,const char *l) = 0;
-    //virtual void endQuickIndexItem() = 0;
+    virtual void endDirDepGraph(const DotDirDeps &g) = 0;
+    virtual void writeGraphicalHierarchy(const DotGfxHierarchyTable &g) = 0;
+    virtual void startQuickIndices() = 0;
+    virtual void endQuickIndices() = 0;
+    virtual void writeSplitBar(const char *) = 0;
+    virtual void writeLogo() = 0;
     virtual void writeQuickLinks(bool compact,HighlightedItem hli) = 0;
+    virtual void startContents() = 0;
+    virtual void endContents() = 0;
     virtual void startTextBlock(bool) = 0;
     virtual void endTextBlock(bool) = 0;
     virtual void lastIndexPage() = 0;
@@ -391,15 +412,12 @@ class OutputGenerator : public BaseOutputDocInterface
     virtual void endConstraintList() = 0;
 
   protected:
-    QTextStream fs;
-    QByteArray a;
-    QBuffer b;
-    QTextStream t;
+    FTextStream t;
     QFile *file;
+    QCString fileName;
     QCString dir;
     bool active;
     QStack<bool> *genStack;
-    QString encoding;
 
   private:
     OutputGenerator(const OutputGenerator &o);
