@@ -69,11 +69,15 @@ bool PageDef::hasParentPage() const
 
 void PageDef::writeDocumentation(OutputList &ol)
 {
+  static bool generateTreeView = Config_getBool("GENERATE_TREEVIEW");
+
   //outputList->disable(OutputGenerator::Man);
   QCString pageName;
   pageName=escapeCharsInString(name(),FALSE,TRUE);
 
-  startFile(ol,getOutputFileBase(),pageName,title(),HLI_Pages,TRUE);
+  //printf("PageDef::writeDocumentation: %s\n",getOutputFileBase().data());
+
+  startFile(ol,getOutputFileBase(),pageName,title(),HLI_Pages,!generateTreeView);
 
   ol.pushGeneratorState();
   //1.{ 
@@ -90,12 +94,15 @@ void PageDef::writeDocumentation(OutputList &ol)
     ol.enable(OutputGenerator::Html);
   }
 
-  if (getOuterScope()!=Doxygen::globalScope && !Config_getBool("DISABLE_INDEX"))
+  if (!generateTreeView)
   {
-    getOuterScope()->writeNavigationPath(ol);
+    if (getOuterScope()!=Doxygen::globalScope && !Config_getBool("DISABLE_INDEX"))
+    {
+      getOuterScope()->writeNavigationPath(ol);
+    }
+    ol.endQuickIndices();
   }
-
-  ol.endQuickIndices();
+  SectionInfo *si=Doxygen::sectionDict.find(name());
 
   // save old generator state and write title only to Man generator
   ol.pushGeneratorState();
@@ -103,6 +110,11 @@ void PageDef::writeDocumentation(OutputList &ol)
   ol.disableAllBut(OutputGenerator::Man);
   ol.startTitleHead(pageName);
   ol.endTitleHead(pageName, pageName);
+  if (si)
+  {
+    ol.parseDoc(docFile(),docLine(),this,0,si->title,TRUE,FALSE,0,TRUE,FALSE);
+    ol.endSection(si->label,si->type);
+  }
   ol.popGeneratorState();
   //2.}
 
@@ -111,9 +123,8 @@ void PageDef::writeDocumentation(OutputList &ol)
   //2.{
   ol.disable(OutputGenerator::Latex);
   ol.disable(OutputGenerator::RTF);
-  SectionInfo *si=0;
-  if (!title().isEmpty() && !name().isEmpty() &&
-      (si=Doxygen::sectionDict.find(name()))!=0)
+  ol.disable(OutputGenerator::Man);
+  if (!title().isEmpty() && !name().isEmpty() && si!=0)
   {
     //ol.startSection(si->label,si->title,si->type);
     startTitle(ol,getOutputFileBase(),this);
@@ -133,7 +144,16 @@ void PageDef::writeDocumentation(OutputList &ol)
   ol.popGeneratorState();
   //1.}
 
-  endFile(ol);
+  if (generateTreeView && getOuterScope()!=Doxygen::globalScope && !Config_getBool("DISABLE_INDEX"))
+  {
+    ol.endContents();
+    getOuterScope()->writeNavigationPath(ol);
+    endFile(ol,TRUE);
+  }
+  else
+  {
+    endFile(ol);
+  }
 
   if (!Config_getString("GENERATE_TAGFILE").isEmpty())
   {
@@ -159,7 +179,7 @@ void PageDef::writeDocumentation(OutputList &ol)
     }
   }
 
-  Doxygen::indexList.addIndexItem(this,0,0,filterTitle(title()));
+  Doxygen::indexList.addIndexItem(this,0,filterTitle(title()));
 }
 
 void PageDef::writePageDocumentation(OutputList &ol)
