@@ -2,7 +2,7 @@
  *
  * 
  *
- * Copyright (C) 1997-2005 by Dimitri van Heesch.
+ * Copyright (C) 1997-2011 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -15,9 +15,9 @@
 #ifndef PERLMODGEN_H
 #define PERLMODGEN_H
 
-class QString;
+class QCString;
 
-extern void setPerlModDoxyfile(const QString &);
+extern void setPerlModDoxyfile(const QCString &);
 extern void generatePerlMod();
 
 #endif
