@@ -1,8 +1,8 @@
 /******************************************************************************
  *
- * 
+ * $Id: searchindex.h,v 1.7 2001/03/19 19:27:41 root Exp $
  *
- * Copyright (C) 1997-2005 by Dimitri van Heesch.
+ * Copyright (C) 1997-2011 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -58,7 +58,7 @@ class SearchIndex
   public:
     SearchIndex();
     void setCurrentDoc(const char *name,const char *baseName,const char *anchor=0);
-    void addWord(const char *word,bool hiPriority);
+    void addWord(const char *word,bool hiPriority,bool recurse=FALSE);
     void write(const char *file);
   private:
     QDict<IndexWord> m_words;
