@@ -3,7 +3,7 @@
  * $Id: $
  *
  *
- * Copyright (C) 1997-2010 by Dimitri van Heesch.
+ * Copyright (C) 1997-2011 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -102,6 +102,9 @@ class TextDocVisitor : public DocVisitor
     void visitPost(DocImage *) {}
     void visitPre(DocDotFile *) {}
     void visitPost(DocDotFile *) {}
+
+    void visitPre(DocMscFile *) {}
+    void visitPost(DocMscFile *) {}
     void visitPre(DocLink *) {}
     void visitPost(DocLink *) {}
     void visitPre(DocRef *) {}
