@@ -2,7 +2,7 @@
  *
  * 
  *
- * Copyright (C) 1997-2010 by Dimitri van Heesch.
+ * Copyright (C) 1997-2011 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -24,7 +24,7 @@
 */
 #define CN_SPC
 
-class TranslatorChinese : public TranslatorAdapter_1_6_0
+class TranslatorChinese : public Translator
 {
   public:
 		/*! Used for identification of the language. The identification
@@ -1787,6 +1787,81 @@ class TranslatorChinese : public TranslatorAdapter_1_6_0
     {
       return "";
     }
+	
+//////////////////////////////////////////////////////////////////////////
+// new since 1.6.0
+//////////////////////////////////////////////////////////////////////////
+	virtual QCString trDirRelation(const char *name)
+	{
+		// return QCString(name)+" Relation";
+		// unsure
+		return QCString(name)+CN_SPC"ϵ";
+	}
+	
+    virtual QCString trLoading()
+	{
+		return "...";
+	}
+    
+	virtual QCString trGlobalNamespace()
+	{
+		return "ȫռ";
+	}
+	
+    virtual QCString trSearching()
+	{
+		return "...";
+	}
+    
+	virtual QCString trNoMatches()
+	{
+		return "δҵ";
+	}
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.6.3
+//////////////////////////////////////////////////////////////////////////
+
+    virtual QCString trDirDependency(const char *name)
+	{
+		// return (QCString)"Directory dependency graph for "+name;
+		// unsure
+		return QCString(name)+CN_SPC"Ŀ¼ϵͼ";
+	}
+    
+	virtual QCString trFileIn(const char *name)
+	{
+		// return (QCString)"File in "+name;
+		// unsure
+		return (QCString)"ļ"+CN_SPC+name;
+	}
+	
+    virtual QCString trIncludesFileIn(const char *name)
+	{
+		// return (QCString)"Includes file in "+name;
+		// unsure
+		return (QCString)""CN_SPC+name+CN_SPC"";
+	}
+
+    virtual QCString trDateTime(int year,int month,int day,int dayOfWeek,
+                                int hour,int minutes,int seconds,
+                                bool includeTime)
+	{
+	  static const char *days[]   = { "һ","","","","","","" };
+      static const char *months[] = { "һ","","","","","","","","","ʮ","ʮһ","ʮ" };
+      
+	  QCString sdate;
+      
+	  sdate.sprintf("%d%s%d %s",year, months[month-1], day, days[dayOfWeek-1]);
+      
+	  if (includeTime)
+      {
+        QCString stime;
+        stime.sprintf(" %.2d:%.2d:%.2d",hour,minutes,seconds);
+        sdate+=stime;
+      }
+      return sdate;
+	}                    
 };
 
 #endif
