@@ -2,7 +2,7 @@
  *
  * 
  *
- * Copyright (C) 1997-2008 by Dimitri van Heesch.
+ * Copyright (C) 1997-2011 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -100,7 +100,7 @@
 // Translator class (by the local maintainer) when the localized
 // translator is made up-to-date again.
 
-class TranslatorFrench : public TranslatorAdapter_1_5_4
+class TranslatorFrench : public TranslatorAdapter_1_6_3
 {
    public:
    
@@ -573,7 +573,7 @@ class TranslatorFrench : public TranslatorAdapter_1_5_4
      */
        virtual QCString trTypedefDocumentation()
       { 
-         return "Documentation des dfinition de type"; }
+         return "Documentation des dfinitions de type"; }
    
     /*! This is used in the documentation of a file/namespace before the list 
      *  of documentation blocks for enumeration types
@@ -1622,7 +1622,7 @@ class TranslatorFrench : public TranslatorAdapter_1_5_4
       {
          if (numDocuments==0)
          {
-            return "Dsol aucun document ne correspond  votre requte.";
+            return "Dsol, aucun document ne correspond  votre requte.";
          }
          else if (numDocuments==1)
          {
@@ -1736,6 +1736,242 @@ class TranslatorFrench : public TranslatorAdapter_1_5_4
      */
     virtual QCString trEnumerationValueDocumentation()
     { return "Documentation des numrations"; }
+
+    //////////////////////////////////////////////////////////////////////////
+    // new since 1.5.4 (mainly for Fortran)
+    //////////////////////////////////////////////////////////////////////////
+    
+    /*! header that is put before the list of member subprograms (Fortran). */
+    virtual QCString trMemberFunctionDocumentationFortran()
+    { return "Documentation des fonctions membres/subroutine"; }
+
+    /*! This is put above each page as a link to the list of annotated data types (Fortran). */    
+    virtual QCString trCompoundListFortran()
+    { return "Liste des types de donnes"; }
+
+    /*! This is put above each page as a link to all members of compounds (Fortran). */
+    virtual QCString trCompoundMembersFortran()
+    { return "Champs de donnes"; }
+
+    /*! This is an introduction to the annotated compound list (Fortran). */
+    virtual QCString trCompoundListDescriptionFortran()
+    { return "Liste des types de donnes avec une brve description :"; }
+
+    /*! This is an introduction to the page with all data types (Fortran). */
+    virtual QCString trCompoundMembersDescriptionFortran(bool extractAll)
+    {
+      QCString result="Liste de tous les ";
+      result+="membres de types de donnes ";
+      if (!extractAll)
+      {
+        result+="documents ";
+      }
+      result+="avec liens vers ";
+      if (!extractAll) 
+      {
+         result+="la documentation de la structure des donnes de chaque membre :";
+      }
+      else 
+      {
+         result+="les types des donnes auxquels ils appartiennent :";
+      }
+      return result;
+    }
+
+    /*! This is used in LaTeX as the title of the chapter with the 
+     * annotated compound index (Fortran).
+     */
+    virtual QCString trCompoundIndexFortran()
+    { return "Index du type de donnes"; }
+
+    /*! This is used in LaTeX as the title of the chapter containing
+     *  the documentation of all data types (Fortran).
+     */
+    virtual QCString trTypeDocumentation()
+    { return "Documentation du type de donnes"; }
+
+    /*! This is used in the documentation of a file as a header before the 
+     *  list of (global) subprograms (Fortran).
+     */
+    virtual QCString trSubprograms()
+    { return "Fonctions/Subroutines"; }
+
+    /*! This is used in the documentation of a file/namespace before the list 
+     *  of documentation blocks for subprograms (Fortran)
+     */
+    virtual QCString trSubprogramDocumentation()
+    { return "Documentation de la Fonction/Subroutine"; }
+
+    /*! This is used in the documentation of a file/namespace/group before 
+     *  the list of links to documented compounds (Fortran)
+     */
+     virtual QCString trDataTypes()
+    { return "Les types de donnes"; }
+    
+    /*! used as the title of page containing all the index of all modules (Fortran). */
+    virtual QCString trModulesList()
+    { return "Liste des modules"; }
+
+    /*! used as an introduction to the modules list (Fortran) */
+    virtual QCString trModulesListDescription(bool extractAll)
+    {
+      QCString result="Liste de tous les modules";
+      if (!extractAll) result+="documents ";
+      result+="avec une brve description :";
+      return result;
+    }
+
+    /*! used as the title of the HTML page of a module/type (Fortran) */
+    virtual QCString trCompoundReferenceFortran(const char *clName,
+                                    ClassDef::CompoundType compType,
+                                    bool isTemplate)
+    {
+      QCString result="Rference ";
+      if (isTemplate) result+="du gabarit (template) ";
+      switch(compType)
+      {
+        case ClassDef::Class:      result+="du module "; break;
+        case ClassDef::Struct:     result+="du type "; break;
+        case ClassDef::Union:      result+="de l'union "; break;
+        case ClassDef::Interface:  result+="de l'interface "; break;
+        case ClassDef::Protocol:   result+="du protocole "; break;
+        case ClassDef::Category:   result+="de la catgorie "; break;
+        case ClassDef::Exception:  result+="de l'exception "; break;
+      }
+      result+=(QCString)clName;
+      return result;
+    }
+    /*! used as the title of the HTML page of a module (Fortran) */
+    virtual QCString trModuleReference(const char *namespaceName)
+    {
+      QCString result="Rfrence du module ";
+      result+= namespaceName;        
+      return result;
+    }
+    
+    /*! This is put above each page as a link to all members of modules. (Fortran) */
+    virtual QCString trModulesMembers()
+    { return "Membres du module"; }
+
+    /*! This is an introduction to the page with all modules members (Fortran) */
+    virtual QCString trModulesMemberDescription(bool extractAll)
+    { 
+      QCString result="Liste de tous les membres ";
+      if (!extractAll) result+="documents ";
+      result+="du module avec lien vers ";
+      if (extractAll) 
+      {
+        result+="la documentation du module de chaque membre :";
+      }
+      else 
+      {
+        result+="les modules auxquels ils appartiennent :";
+      }
+      return result;
+    }
+
+    /*! This is used in LaTeX as the title of the chapter with the 
+     *  index of all modules (Fortran).
+     */
+    virtual QCString trModulesIndex()
+    { return "Index des modules"; }
+    
+    /*! This is used for translation of the word that will possibly
+     *  be followed by a single name or by a list of names 
+     *  of the category.
+     */
+    virtual QCString trModule(bool first_capital, bool singular)
+    {       
+      QCString result((first_capital ? "Module" : "module"));
+      if (!singular)  result+="s";
+      return result; 
+    }
+
+    /*! This is put at the bottom of a module documentation page and is
+     *  followed by a list of files that were used to generate the page.
+     */
+    virtual QCString trGeneratedFromFilesFortran(ClassDef::CompoundType compType,
+        bool single)
+    {
+      // single is true implies a single file
+      QCString result=(QCString)"La documentation de ";
+      switch(compType)
+      {
+        case ClassDef::Class:      result+="ce module"; break;
+        case ClassDef::Struct:     result+="ce type"; break;
+        case ClassDef::Union:      result+="cette union"; break;
+        case ClassDef::Interface:  result+="cette interface"; break;
+        case ClassDef::Protocol:   result+="ce protocole"; break;
+        case ClassDef::Category:   result+="cette catgorie"; break;
+        case ClassDef::Exception:  result+="cette exception"; break;
+      }
+      result+=" a t gnre  partir ";
+      if (single) result+="du fichier suivant :"; else result+="des fichiers suivants :";
+      return result;
+    }
+
+    /*! This is used for translation of the word that will possibly
+     *  be followed by a single name or by a list of names 
+     *  of the category.
+     */
+    virtual QCString trType(bool first_capital, bool singular)
+    { 
+      QCString result((first_capital ? "Type" : "type"));
+      if (!singular)  result+="s";
+      return result; 
+    }
+
+    /*! This is used for translation of the word that will possibly
+     *  be followed by a single name or by a list of names 
+     *  of the category.
+     */
+    virtual QCString trSubprogram(bool first_capital, bool singular)
+    { 
+      QCString result((first_capital ? "Sous-programme" : "sous-programme"));
+      if (!singular)  result+="s";
+      return result; 
+    }
+
+    /*! C# Type Constraint list */
+    virtual QCString trTypeConstraints()
+    {
+      return "Les constraintes du type";
+    }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.6.0 (mainly for the new search engine)
+//////////////////////////////////////////////////////////////////////////
+
+    /*! directory relation for \a name */
+    virtual QCString trDirRelation(const char *name)
+    {
+      return "Relation " + QCString(name);
+    }
+
+    /*! Loading message shown when loading search results */
+    virtual QCString trLoading()
+    {
+      return "Chargement...";
+    }
+
+    /*! Label used for search results in the global namespace */
+    virtual QCString trGlobalNamespace()
+    {
+      return "Espace de nommage global";
+    }
+
+    /*! Message shown while searching */
+    virtual QCString trSearching()
+    {
+      return "Recherche...";
+    }
+
+    /*! Text shown when no search results are found */
+    virtual QCString trNoMatches()
+    {
+      return "Aucune correspondance";
+    }
+
 };
 
 #endif
