@@ -3,7 +3,7 @@
  * $Id: $
  *
  *
- * Copyright (C) 1997-2010 by Dimitri van Heesch.
+ * Copyright (C) 1997-2011 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -76,6 +76,7 @@ void XmlDocVisitor::visit(DocSymbol *s)
     case DocSymbol::Amp:     m_t << "&amp;"; break;
     case DocSymbol::Dollar:  m_t << "$"; break;
     case DocSymbol::Hash:    m_t << "#"; break;
+    case DocSymbol::DoubleColon: m_t << "::"; break;
     case DocSymbol::Percent: m_t << "%"; break;
     case DocSymbol::Copy:    m_t << "<copy/>"; break;
     case DocSymbol::Tm:      m_t << "<trademark/>"; break;
@@ -711,6 +712,17 @@ void XmlDocVisitor::visitPost(DocDotFile *)
   m_t << "</dotfile>" << endl;
 }
 
+void XmlDocVisitor::visitPre(DocMscFile *df)
+{
+  if (m_hide) return;
+  m_t << "<mscfile name=\"" << df->file() << "\">";
+}
+
+void XmlDocVisitor::visitPost(DocMscFile *) 
+{
+  if (m_hide) return;
+  m_t << "</mscfile>" << endl;
+}
 void XmlDocVisitor::visitPre(DocLink *lnk)
 {
   if (m_hide) return;
@@ -810,6 +822,24 @@ void XmlDocVisitor::visitPre(DocParamList *pl)
   DocNode *param;
   for (li.toFirst();(param=li.current());++li)
   {
+    if (pl->paramTypes().count()>0)
+    {
+      QListIterator<DocNode> li(pl->paramTypes());
+      DocNode *type;
+      for (li.toFirst();(type=li.current());++li)
+      {
+        m_t << "<parametertype>";
+        if (type->kind()==DocNode::Kind_Word)
+        {
+          visit((DocWord*)type); 
+        }
+        else if (type->kind()==DocNode::Kind_LinkedWord)
+        {
+          visit((DocLinkedWord*)type); 
+        }
+        m_t << "</parametertype>" << endl;
+      }
+    }
     m_t << "<parametername";
     if (pl->direction()!=DocParamSect::Unspecified)
     {
