@@ -3,7 +3,7 @@
  * $Id: xml.cpp,v 1.2 2001/01/01 10:15:18 root Exp $
  *
  *
- * Copyright (C) 1997-2008 by Dimitri van Heesch.
+ * Copyright (C) 1997-2011 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -108,12 +108,12 @@ class XmlSectionMapper : public QIntDict<char>
 static XmlSectionMapper g_xmlSectionMapper;
 
 
-inline void writeXMLString(QTextStream &t,const char *s)
+inline void writeXMLString(FTextStream &t,const char *s)
 {
   t << convertToXML(s);
 }
 
-inline void writeXMLCodeString(QTextStream &t,const char *s, int &col)
+inline void writeXMLCodeString(FTextStream &t,const char *s, int &col)
 {
   char c;
   while ((c=*s++))
@@ -140,7 +140,7 @@ inline void writeXMLCodeString(QTextStream &t,const char *s, int &col)
 }
 
 
-static void writeXMLHeader(QTextStream &t)
+static void writeXMLHeader(FTextStream &t)
 {
   t << "<?xml version='1.0' encoding='UTF-8' standalone='no'?>" << endl;;
   t << "<doxygen xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\" ";
@@ -158,8 +158,8 @@ static void writeCombineScript()
     err("Cannot open file %s for writing!\n",fileName.data());
     return;
   }
-  QTextStream t(&f);
-  t.setEncoding(QTextStream::UnicodeUTF8);
+  FTextStream t(&f);
+  //t.setEncoding(FTextStream::UnicodeUTF8);
 
   t <<
   "<!-- XSLT script to combine the generated output into a single file. \n"
@@ -167,7 +167,7 @@ static void writeCombineScript()
   "     xsltproc combine.xslt index.xml >all.xml\n"
   "-->\n"
   "<xsl:stylesheet xmlns:xsl=\"http://www.w3.org/1999/XSL/Transform\" version=\"1.0\">\n"
-  "  <xsl:output method=\"xml\" version=\"1.0\" indent=\"yes\" standalone=\"yes\" />\n"
+  "  <xsl:output method=\"xml\" version=\"1.0\" indent=\"no\" standalone=\"yes\" />\n"
   "  <xsl:template match=\"/\">\n"
   "    <doxygen version=\"{doxygenindex/@version}\">\n"
   "      <!-- Load all doxgen generated xml files -->\n"
@@ -180,7 +180,7 @@ static void writeCombineScript()
 
 }
 
-void writeXMLLink(QTextStream &t,const char *extRef,const char *compoundId,
+void writeXMLLink(FTextStream &t,const char *extRef,const char *compoundId,
                   const char *anchorId,const char *text,const char *tooltip)
 {
   t << "<ref refid=\"" << compoundId;
@@ -198,7 +198,7 @@ void writeXMLLink(QTextStream &t,const char *extRef,const char *compoundId,
 class TextGeneratorXMLImpl : public TextGeneratorIntf
 {
   public:
-    TextGeneratorXMLImpl(QTextStream &t): m_t(t) {}
+    TextGeneratorXMLImpl(FTextStream &t): m_t(t) {}
     void writeString(const char *s,bool /*keepSpaces*/) const
     {
       writeXMLString(m_t,s); 
@@ -211,7 +211,7 @@ class TextGeneratorXMLImpl : public TextGeneratorIntf
       writeXMLLink(m_t,extRef,file,anchor,text,0);
     }
   private:
-    QTextStream &m_t;
+    FTextStream &m_t;
 };
 
 template<class T> class ValStack
@@ -272,7 +272,7 @@ class XMLCodeGenerator : public CodeOutputInterface
 {
   public:
 
-    XMLCodeGenerator(QTextStream &t) : m_t(t), m_lineNumber(-1),
+    XMLCodeGenerator(FTextStream &t) : m_t(t), m_lineNumber(-1),
       m_insideCodeLine(FALSE), m_normalHLNeedStartTag(TRUE), 
       m_insideSpecialHL(FALSE) {}
     virtual ~XMLCodeGenerator() { }
@@ -403,7 +403,7 @@ class XMLCodeGenerator : public CodeOutputInterface
     }
 
   private:
-    QTextStream &m_t;  
+    FTextStream &m_t;  
     QCString m_refId;
     QCString m_external;
     int m_lineNumber;
@@ -417,7 +417,7 @@ class XMLCodeGenerator : public CodeOutputInterface
 
 
 static void writeTemplateArgumentList(ArgumentList *al,
-                                      QTextStream &t,
+                                      FTextStream &t,
                                       Definition *scope,
                                       FileDef *fileScope,
                                       int indent)
@@ -455,7 +455,7 @@ static void writeTemplateArgumentList(ArgumentList *al,
   }
 }
 
-static void writeMemberTemplateLists(MemberDef *md,QTextStream &t)
+static void writeMemberTemplateLists(MemberDef *md,FTextStream &t)
 {
   LockingPtr<ArgumentList> templMd = md->templateArguments();
   if (templMd!=0) // function template prefix
@@ -464,12 +464,12 @@ static void writeMemberTemplateLists(MemberDef *md,QTextStream &t)
   }
 }
 
-static void writeTemplateList(ClassDef *cd,QTextStream &t)
+static void writeTemplateList(ClassDef *cd,FTextStream &t)
 {
   writeTemplateArgumentList(cd->templateArguments(),t,cd,0,4);
 }
 
-static void writeXMLDocBlock(QTextStream &t,
+static void writeXMLDocBlock(FTextStream &t,
                       const QCString &fileName,
                       int lineNr,
                       Definition *scope,
@@ -493,7 +493,7 @@ static void writeXMLDocBlock(QTextStream &t,
   
 }
 
-void writeXMLCodeBlock(QTextStream &t,FileDef *fd)
+void writeXMLCodeBlock(FTextStream &t,FileDef *fd)
 {
   ParserInterface *pIntf=Doxygen::parserManager->getParser(fd->getDefFileExtension());
   pIntf->resetCodeParserState();
@@ -508,7 +508,7 @@ void writeXMLCodeBlock(QTextStream &t,FileDef *fd)
   delete xmlGen;
 }
 
-static void writeMemberReference(QTextStream &t,Definition *def,MemberDef *rmd,const char *tagName)
+static void writeMemberReference(FTextStream &t,Definition *def,MemberDef *rmd,const char *tagName)
 {
   QCString scope = rmd->getScopeString();
   QCString name = rmd->name();
@@ -544,7 +544,26 @@ static void stripQualifiers(QCString &typeStr)
   }
 }
 
-static void generateXMLForMember(MemberDef *md,QTextStream &ti,QTextStream &t,Definition *def)
+static QCString classOutputFileBase(ClassDef *cd)
+{
+  static bool inlineGroupedClasses = Config_getBool("INLINE_GROUPED_CLASSES");
+  if (inlineGroupedClasses && cd->partOfGroups()!=0) 
+    return cd->getXmlOutputFileBase();
+  else 
+    return cd->getOutputFileBase();
+}
+
+static QCString memberOutputFileBase(MemberDef *md)
+{
+  static bool inlineGroupedClasses = Config_getBool("INLINE_GROUPED_CLASSES");
+  if (inlineGroupedClasses && md->getClassDef() && md->getClassDef()->partOfGroups()!=0) 
+    return md->getClassDef()->getXmlOutputFileBase();
+  else 
+    return md->getOutputFileBase();
+}
+
+
+static void generateXMLForMember(MemberDef *md,FTextStream &ti,FTextStream &t,Definition *def)
 {
 
   // + declaration/definition arg lists
@@ -564,7 +583,7 @@ static void generateXMLForMember(MemberDef *md,QTextStream &ti,QTextStream &t,De
   // enum values are written as part of the enum
   if (md->memberType()==MemberDef::EnumValue) return;
   if (md->isHidden()) return;
-  if (md->name().at(0)=='@') return; // anonymous member
+  //if (md->name().at(0)=='@') return; // anonymous member
 
   // group members are only visible in their group
   //if (def->definitionType()!=Definition::TypeGroup && md->getGroupDef()) return;
@@ -582,13 +601,12 @@ static void generateXMLForMember(MemberDef *md,QTextStream &ti,QTextStream &t,De
     case MemberDef::Enumeration: memType="enum";      break;
     case MemberDef::Function:    memType="function";  isFunc=TRUE; break;
     case MemberDef::Signal:      memType="signal";    isFunc=TRUE; break;
-    case MemberDef::Prototype:   memType="prototype"; isFunc=TRUE; break;
     case MemberDef::Friend:      memType="friend";    isFunc=TRUE; break;
     case MemberDef::DCOP:        memType="dcop";      isFunc=TRUE; break;
     case MemberDef::Slot:        memType="slot";      isFunc=TRUE; break;
   }
 
-  ti << "    <member refid=\"" << md->getOutputFileBase() 
+  ti << "    <member refid=\"" << memberOutputFileBase(md) 
      << "_1" << md->anchor() << "\" kind=\"" << memType << "\"><name>" 
      << convertToXML(md->name()) << "</name></member>" << endl;
   
@@ -607,7 +625,7 @@ static void generateXMLForMember(MemberDef *md,QTextStream &ti,QTextStream &t,De
   }
   else
   {
-    t << md->getOutputFileBase();
+    t << memberOutputFileBase(md);
   }
   t << "_1"      // encoded `:' character (see util.cpp:convertNameToFile)
     << md->anchor();
@@ -655,6 +673,16 @@ static void generateXMLForMember(MemberDef *md,QTextStream &ti,QTextStream &t,De
       t << " new=\"yes\"";
     }
 
+    if (md->isOptional())
+    {
+      t << " optional=\"yes\"";
+    }
+
+    if (md->isRequired())
+    {
+      t << " required=\"yes\"";
+    }
+
     t << " virt=\"";
     switch (md->virtualness())
     {
@@ -699,6 +727,15 @@ static void generateXMLForMember(MemberDef *md,QTextStream &ti,QTextStream &t,De
     t << " settable=\"";
     if (md->isSettable()) t << "yes"; else t << "no";
     t << "\"";
+
+    if (md->isAssign() || md->isCopy() || md->isRetain())
+    {
+      t << " accessor=\"";
+      if (md->isAssign()) t << "assign";
+      else if (md->isCopy()) t << "copy";
+      else if (md->isRetain()) t << "retain";
+      t << "\"";
+    }
   }
   else if (md->memberType() == MemberDef::Event)
   {
@@ -754,7 +791,7 @@ static void generateXMLForMember(MemberDef *md,QTextStream &ti,QTextStream &t,De
   if (rmd)
   {
     t << "        <reimplements refid=\"" 
-      << rmd->getOutputFileBase() << "_1" << rmd->anchor() << "\">"
+      << memberOutputFileBase(rmd) << "_1" << rmd->anchor() << "\">"
       << convertToXML(rmd->name()) << "</reimplements>" << endl;
   }
   LockingPtr<MemberList> rbml = md->reimplementedBy();
@@ -764,7 +801,7 @@ static void generateXMLForMember(MemberDef *md,QTextStream &ti,QTextStream &t,De
     for (mli.toFirst();(rmd=mli.current());++mli)
     {
       t << "        <reimplementedby refid=\"" 
-        << rmd->getOutputFileBase() << "_1" << rmd->anchor() << "\">"
+        << memberOutputFileBase(rmd) << "_1" << rmd->anchor() << "\">"
         << convertToXML(rmd->name()) << "</reimplementedby>" << endl;
     }
   }
@@ -873,11 +910,11 @@ static void generateXMLForMember(MemberDef *md,QTextStream &ti,QTextStream &t,De
       MemberDef *emd;
       for (emli.toFirst();(emd=emli.current());++emli)
       {
-        ti << "    <member refid=\"" << emd->getOutputFileBase() 
+        ti << "    <member refid=\"" << memberOutputFileBase(emd) 
            << "_1" << emd->anchor() << "\" kind=\"enumvalue\"><name>" 
            << convertToXML(emd->name()) << "</name></member>" << endl;
 
-        t << "        <enumvalue id=\"" << emd->getOutputFileBase() << "_1" 
+        t << "        <enumvalue id=\"" << memberOutputFileBase(emd) << "_1" 
           << emd->anchor() << "\" prot=\"";
         switch (emd->protection())
         {
@@ -958,7 +995,7 @@ static void generateXMLForMember(MemberDef *md,QTextStream &ti,QTextStream &t,De
   t << "      </memberdef>" << endl;
 }
 
-static void generateXMLSection(Definition *d,QTextStream &ti,QTextStream &t,
+static void generateXMLSection(Definition *d,FTextStream &ti,FTextStream &t,
                       MemberList *ml,const char *kind,const char *header=0,
                       const char *documentation=0)
 {
@@ -1000,7 +1037,7 @@ static void generateXMLSection(Definition *d,QTextStream &ti,QTextStream &t,
   t << "      </sectiondef>" << endl;
 }
 
-static void writeListOfAllMembers(ClassDef *cd,QTextStream &t)
+static void writeListOfAllMembers(ClassDef *cd,FTextStream &t)
 {
   t << "    <listofallmembers>" << endl;
   if (cd->memberNameInfoSDict())
@@ -1018,7 +1055,7 @@ static void writeListOfAllMembers(ClassDef *cd,QTextStream &t)
         {
           Protection prot = mi->prot;
           Specifier virt=md->virtualness();
-          t << "      <member refid=\"" << md->getOutputFileBase() << "_1" <<
+          t << "      <member refid=\"" << memberOutputFileBase(md) << "_1" <<
             md->anchor() << "\" prot=\"";
           switch (prot)
           {
@@ -1048,7 +1085,7 @@ static void writeListOfAllMembers(ClassDef *cd,QTextStream &t)
   t << "    </listofallmembers>" << endl;
 }
 
-static void writeInnerClasses(const ClassSDict *cl,QTextStream &t)
+static void writeInnerClasses(const ClassSDict *cl,FTextStream &t)
 {
   if (cl)
   {
@@ -1073,7 +1110,7 @@ static void writeInnerClasses(const ClassSDict *cl,QTextStream &t)
   }
 }
 
-static void writeInnerNamespaces(const NamespaceSDict *nl,QTextStream &t)
+static void writeInnerNamespaces(const NamespaceSDict *nl,FTextStream &t)
 {
   if (nl)
   {
@@ -1090,7 +1127,7 @@ static void writeInnerNamespaces(const NamespaceSDict *nl,QTextStream &t)
   }
 }
 
-static void writeInnerFiles(const FileList *fl,QTextStream &t)
+static void writeInnerFiles(const FileList *fl,FTextStream &t)
 {
   if (fl)
   {
@@ -1104,7 +1141,7 @@ static void writeInnerFiles(const FileList *fl,QTextStream &t)
   }
 }
 
-static void writeInnerPages(const PageSDict *pl,QTextStream &t)
+static void writeInnerPages(const PageSDict *pl,FTextStream &t)
 {
   if (pl)
   {
@@ -1122,7 +1159,7 @@ static void writeInnerPages(const PageSDict *pl,QTextStream &t)
   }
 }
 
-static void writeInnerGroups(const GroupList *gl,QTextStream &t)
+static void writeInnerGroups(const GroupList *gl,FTextStream &t)
 {
   if (gl)
   {
@@ -1137,7 +1174,7 @@ static void writeInnerGroups(const GroupList *gl,QTextStream &t)
   }
 }
 
-static void writeInnerDirs(const DirList *dl,QTextStream &t)
+static void writeInnerDirs(const DirList *dl,FTextStream &t)
 {
   if (dl)
   {
@@ -1151,8 +1188,7 @@ static void writeInnerDirs(const DirList *dl,QTextStream &t)
   }
 }
   
-
-static void generateXMLForClass(ClassDef *cd,QTextStream &ti)
+static void generateXMLForClass(ClassDef *cd,FTextStream &ti)
 {
   // + brief description
   // + detailed description
@@ -1169,7 +1205,7 @@ static void generateXMLForClass(ClassDef *cd,QTextStream &ti)
   // + standard member sections
   // + detailed member documentation
   // - examples using the class
-  
+
   if (cd->isReference())        return; // skip external references.
   if (cd->isHidden())           return; // skip hidden classes.
   if (cd->name().find('@')!=-1) return; // skip anonymous compounds.
@@ -1177,24 +1213,24 @@ static void generateXMLForClass(ClassDef *cd,QTextStream &ti)
 
   msg("Generating XML output for class %s\n",cd->name().data());
 
-  ti << "  <compound refid=\"" << cd->getOutputFileBase() 
+  ti << "  <compound refid=\"" << classOutputFileBase(cd) 
      << "\" kind=\"" << cd->compoundTypeString()
      << "\"><name>" << convertToXML(cd->name()) << "</name>" << endl;
   
   QCString outputDirectory = Config_getString("XML_OUTPUT");
-  QCString fileName=outputDirectory+"/"+cd->getOutputFileBase()+".xml";
+  QCString fileName=outputDirectory+"/"+ classOutputFileBase(cd)+".xml";
   QFile f(fileName);
   if (!f.open(IO_WriteOnly))
   {
     err("Cannot open file %s for writing!\n",fileName.data());
     return;
   }
-  QTextStream t(&f);
-  t.setEncoding(QTextStream::UnicodeUTF8);
+  FTextStream t(&f);
+  //t.setEncoding(FTextStream::UnicodeUTF8);
 
   writeXMLHeader(t);
   t << "  <compounddef id=\"" 
-    << cd->getOutputFileBase() << "\" kind=\"" 
+    << classOutputFileBase(cd) << "\" kind=\"" 
     << cd->compoundTypeString() << "\" prot=\"";
   switch (cd->protection())
   {
@@ -1216,7 +1252,7 @@ static void generateXMLForClass(ClassDef *cd,QTextStream &ti)
       t << "    <basecompoundref ";
       if (bcd->classDef->isLinkable())
       {
-        t << "refid=\"" << bcd->classDef->getOutputFileBase() << "\" ";
+        t << "refid=\"" << classOutputFileBase(bcd->classDef) << "\" ";
       }
       t << "prot=\"";
       switch (bcd->prot)
@@ -1255,7 +1291,7 @@ static void generateXMLForClass(ClassDef *cd,QTextStream &ti)
     for (bcli.toFirst();(bcd=bcli.current());++bcli)
     {
       t << "    <derivedcompoundref refid=\"" 
-        << bcd->classDef->getOutputFileBase()
+        << classOutputFileBase(bcd->classDef)
         << "\" prot=\"";
       switch (bcd->prot)
       {
@@ -1390,7 +1426,7 @@ static void generateXMLForClass(ClassDef *cd,QTextStream &ti)
   ti << "  </compound>" << endl;
 }
 
-static void generateXMLForNamespace(NamespaceDef *nd,QTextStream &ti)
+static void generateXMLForNamespace(NamespaceDef *nd,FTextStream &ti)
 {
   // + contained class definitions
   // + contained namespace definitions
@@ -1415,8 +1451,8 @@ static void generateXMLForNamespace(NamespaceDef *nd,QTextStream &ti)
     err("Cannot open file %s for writing!\n",fileName.data());
     return;
   }
-  QTextStream t(&f);
-  t.setEncoding(QTextStream::UnicodeUTF8);
+  FTextStream t(&f);
+  //t.setEncoding(FTextStream::UnicodeUTF8);
   
   writeXMLHeader(t);
   t << "  <compounddef id=\"" 
@@ -1472,7 +1508,7 @@ static void generateXMLForNamespace(NamespaceDef *nd,QTextStream &ti)
   ti << "  </compound>" << endl;
 }
 
-static void generateXMLForFile(FileDef *fd,QTextStream &ti)
+static void generateXMLForFile(FileDef *fd,FTextStream &ti)
 {
   // + includes files
   // + includedby files
@@ -1502,8 +1538,8 @@ static void generateXMLForFile(FileDef *fd,QTextStream &ti)
     err("Cannot open file %s for writing!\n",fileName.data());
     return;
   }
-  QTextStream t(&f);
-  t.setEncoding(QTextStream::UnicodeUTF8);
+  FTextStream t(&f);
+  //t.setEncoding(FTextStream::UnicodeUTF8);
 
   writeXMLHeader(t);
   t << "  <compounddef id=\"" 
@@ -1619,7 +1655,7 @@ static void generateXMLForFile(FileDef *fd,QTextStream &ti)
   ti << "  </compound>" << endl;
 }
 
-static void generateXMLForGroup(GroupDef *gd,QTextStream &ti)
+static void generateXMLForGroup(GroupDef *gd,FTextStream &ti)
 {
   // + members
   // + member groups
@@ -1647,8 +1683,8 @@ static void generateXMLForGroup(GroupDef *gd,QTextStream &ti)
     return;
   }
 
-  QTextStream t(&f);
-  t.setEncoding(QTextStream::UnicodeUTF8);
+  FTextStream t(&f);
+  //t.setEncoding(FTextStream::UnicodeUTF8);
   writeXMLHeader(t);
   t << "  <compounddef id=\"" 
     << gd->getOutputFileBase() << "\" kind=\"group\">" << endl;
@@ -1702,7 +1738,7 @@ static void generateXMLForGroup(GroupDef *gd,QTextStream &ti)
   ti << "  </compound>" << endl;
 }
 
-static void generateXMLForDir(DirDef *dd,QTextStream &ti)
+static void generateXMLForDir(DirDef *dd,FTextStream &ti)
 {
   if (dd->isReference()) return; // skip external references
   ti << "  <compound refid=\"" << dd->getOutputFileBase() 
@@ -1718,8 +1754,8 @@ static void generateXMLForDir(DirDef *dd,QTextStream &ti)
     return;
   }
 
-  QTextStream t(&f);
-  t.setEncoding(QTextStream::UnicodeUTF8);
+  FTextStream t(&f);
+  //t.setEncoding(FTextStream::UnicodeUTF8);
   writeXMLHeader(t);
   t << "  <compounddef id=\"" 
     << dd->getOutputFileBase() << "\" kind=\"dir\">" << endl;
@@ -1741,7 +1777,7 @@ static void generateXMLForDir(DirDef *dd,QTextStream &ti)
   ti << "  </compound>" << endl;
 }
 
-static void generateXMLForPage(PageDef *pd,QTextStream &ti,bool isExample)
+static void generateXMLForPage(PageDef *pd,FTextStream &ti,bool isExample)
 {
   // + name
   // + title
@@ -1771,8 +1807,8 @@ static void generateXMLForPage(PageDef *pd,QTextStream &ti,bool isExample)
     return;
   }
 
-  QTextStream t(&f);
-  t.setEncoding(QTextStream::UnicodeUTF8);
+  FTextStream t(&f);
+  //t.setEncoding(FTextStream::UnicodeUTF8);
   writeXMLHeader(t);
   t << "  <compounddef id=\"" << pageName;
   t << "\" kind=\"" << kindName << "\">" << endl;
@@ -1784,6 +1820,7 @@ static void generateXMLForPage(PageDef *pd,QTextStream &ti,bool isExample)
   {
     t << "    <title>" << convertToXML(si->title) << "</title>" << endl;
   }
+  writeInnerPages(pd->getSubPages(),t);
   t << "    <detaileddescription>" << endl;
   if (isExample)
   {
@@ -1826,13 +1863,13 @@ void generateXML()
       dir.setPath(QDir::currentDirPath());
       if (!dir.mkdir(outputDirectory))
       {
-        err("Error: tag XML_OUTPUT: Output directory `%s' does not "
+        err("error: tag XML_OUTPUT: Output directory `%s' does not "
             "exist and cannot be created\n",outputDirectory.data());
         exit(1);
       }
       else if (!Config_getBool("QUIET"))
       {
-        err("Notice: Output directory `%s' does not exist. "
+        err("notice: Output directory `%s' does not exist. "
             "I have created it for you.\n", outputDirectory.data());
       }
       dir.cd(outputDirectory);
@@ -1879,8 +1916,8 @@ void generateXML()
     err("Cannot open file %s for writing!\n",fileName.data());
     return;
   }
-  QTextStream t(&f);
-  t.setEncoding(QTextStream::UnicodeUTF8);
+  FTextStream t(&f);
+  //t.setEncoding(FTextStream::UnicodeUTF8);
 
   // write index header
   t << "<?xml version='1.0' encoding='UTF-8' standalone='no'?>" << endl;;
